@@ -1,7 +1,7 @@
 <?
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balanceview.php,v 1.10.2.2 2005/06/21 11:31:12 alec Exp $
+ *  $Id: balanceview.php,v 1.15 2005/06/29 20:40:04 hunter Exp $
  */
 
 include_once('class.php');
@@ -30,22 +30,24 @@ include_once('authentication.inc');
 $layout['pagetitle'] = trans('Customer Logon');
 
 $loginform = $_POST['loginform'];
-$login = ($loginform['login'] ? trim($loginform['login']) : 0);
-$pin = ($loginform['pwd'] ? trim($loginform['pwd']) : 0);
+$login = (trim($loginform['login']) ? trim($loginform['login']) : 0);
+$pin = (trim($loginform['pwd']) ? trim($loginform['pwd']) : 0);
 
 // customer authorization ways
-//$id = GetUserIDByPhone1AndPIN($login, $pin);
-//$id = GetUserIDByContractAndPIN($login, $pin);
-$id = GetUserIDByIDAndPIN($login, $pin);
+//$id = GetCustomerIDByPhone1AndPIN($login, $pin);
+//$id = GetCustomerIDByContractAndPIN($login, $pin);
+$id = GetCustomerIDByIDAndPIN($login, $pin);
 
 if($id)
 {
 	session_start();
 	$_SESSION['uid'] = $id;
 
-	$SMARTY->assign('userinfo',$LMS->GetUser($id));
-	$SMARTY->assign('balancelist',$LMS->GetUserBalanceList($id));
+	$SMARTY->assign('customerinfo',$LMS->GetCustomer($id));
+	$SMARTY->assign('balancelist',$LMS->GetCustomerBalanceList($id));
 	$SMARTY->assign('limit',15);
+	$SMARTY->assign('account_no',$CONFIG['finances']['account']);
+	$SMARTY->assign('bank_name',$CONFIG['finances']['bank']);
 	$SMARTY->display('balanceview.html');
 }
 else
