@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice_pdf.php,v 1.1.2.1 2005/05/13 20:09:47 alec Exp $
+ *  $Id: invoice_pdf.php,v 1.7 2005/08/04 19:05:30 alec Exp $
  */
 // Faktury w PDF, do uycia z formularzami FT-0100 (c) Polarnet
 // w razie pyta mailto:lexx@polarnet.org
@@ -35,8 +35,8 @@ function text_autosize($x,$y,$size,$text,$width)
 
 function invoice_simple_form_fill($x,$y,$scale)  
 {
-    global $pdf,$invoice,$_CONFIG;
-    $finances = $_CONFIG['finances'];
+    global $pdf,$invoice,$CONFIG;
+    $finances = $CONFIG['finances'];
     $pdf->setlinestyle(1);
 
     $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
@@ -61,20 +61,15 @@ function invoice_simple_form_fill($x,$y,$scale)
     text_autosize(15*$scale+$x,356*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['address']),350*$scale);
     text_autosize(15*$scale+$x,322*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['zip']." ".$invoice['city']),350*$scale);
 
-    $tmp = $_CONFIG['invoices'];
-    $tmp = iconv("UTF-8","ISO-8859-2",$tmp['number_template']);
-    $tmp = str_replace("%N",$invoice['number'],$tmp);
-    $tmp = str_replace("%Y",$invoice['year'],$tmp);
-    $tmp = str_replace("%M",$invoice['month'],$tmp);
-
+    $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
     text_autosize(15*$scale+$x,215*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('Payment for invoice No. $0',$tmp)),350*$scale);
 
 }
 
 function invoice_main_form_fill($x,$y,$scale)	
 {
-    global $pdf,$invoice,$_CONFIG;
-    $finances = $_CONFIG['finances'];
+    global $pdf,$invoice,$CONFIG;
+    $finances = $CONFIG['finances'];
     $pdf->setlinestyle(1);
 
     $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
@@ -92,13 +87,9 @@ function invoice_main_form_fill($x,$y,$scale)
     text_autosize(15*$scale+$x,434*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('$0 dollars $1 cents',to_words(floor($invoice['total'])),to_words(round(($invoice['total']-floor($invoice['total']))*100)))),950*$scale);
     text_autosize(15*$scale+$x,372*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['name']),950*$scale);
     text_autosize(15*$scale+$x,312*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['address']." ".$invoice['zip']." ".$invoice['city']),950*$scale);
-    $tmp = $_CONFIG['invoices'];
-    $tmp = iconv("UTF-8","ISO-8859-2",$tmp['number_template']);
-    $tmp = str_replace("%N",$invoice['number'],$tmp);
-    $tmp = str_replace("%Y",$invoice['year'],$tmp);
-    $tmp = str_replace("%M",$invoice['month'],$tmp);
-    text_autosize(15*$scale+$x,250*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('Payment for invoice No. $0',$tmp)),950*$scale);
 
+    $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
+    text_autosize(15*$scale+$x,250*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('Payment for invoice No. $0',$tmp)),950*$scale);
 }
 
 function text_align_right($x,$y,$size,$text) 
@@ -148,20 +139,20 @@ function invoice_buyer($x,$y)
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['address']));
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['zip']." ".$invoice['city']));
     if ($invoice['phone']) $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('Phone:').' '.$invoice['phone']));
-    if ($invoice['nip']) 
-	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('TEN:')).' '.$invoice['nip']);
-    else if ($invoice['pesel']) 
-	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('SSN:')).' '.$invoice['pesel']);
+    if ($invoice['ten']) 
+	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('TEN:')).' '.$invoice['ten']);
+    else if ($invoice['ssn']) 
+	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('SSN:')).' '.$invoice['ssn']);
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Customer No.: $0',sprintf('%04d',$invoice['customerid']))).'</b>');
     return $y;
 }
 
 function invoice_seller($x,$y) 
 {
-    global $pdf,$_CONFIG;
+    global $pdf,$CONFIG;
     $font_size=10;
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Seller:')).'</b>');
-    $tmp = iconv("UTF-8","ISO-8859-2",$_CONFIG['invoices']['header']);
+    $tmp = iconv("UTF-8","ISO-8859-2",$CONFIG['invoices']['header']);
     $tmp = str_replace('\n',"\n",$tmp);
     $tmp = explode("\n",$tmp);
     foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,$line);
@@ -171,12 +162,9 @@ function invoice_seller($x,$y)
 
 function invoice_title($x,$y) 
 {
-    global $invoice,$pdf,$_CONFIG,$type;
+    global $invoice,$pdf,$CONFIG,$type;
     $font_size=16;
-    $tmp = $_CONFIG['invoices']['number_template'];
-    $tmp = str_replace("%N",$invoice['number'],$tmp);
-    $tmp = str_replace("%Y",$invoice['year'],$tmp);
-    $tmp = str_replace("%M",$invoice['month'],$tmp);
+    $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Invoice No. $0',$tmp)).'</b>');
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$type));
     return $y;
@@ -262,12 +250,12 @@ function invoice_data($x,$y,$width,$font_size,$margin)
     // tutaj jeszcze trzeba bdzie sprawdzi jak szeroko maj pola w tabelce puniej
     if ($invoice['content']) foreach ($invoice['content'] as $item) {
 	$tt_width[2] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",$item['description']));
-	$tt_width[3] = $pdf->getTextWidth($font_size,$item['pkwiu']);
+	$tt_width[3] = $pdf->getTextWidth($font_size,$item['prodid']);
 	$tt_width[4] = $pdf->getTextWidth($font_size,$item['content']);
 	$tt_width[5] = $pdf->getTextWidth($font_size,$item['count']);
 	$tt_width[6] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['basevalue'])));
 	$tt_width[7] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['totalbase'])));
-	$tt_width[8] = $pdf->getTextWidth($font_size,$item['taxvalue']." %");
+	$tt_width[8] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",$item['taxlabel']));
 	$tt_width[9] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['totaltax'])));
 	$tt_width[10] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['total'])));
 	for ($i = 2; $i <= 5; $i++) if (($tt_width[$i]+2*margin+2)>$t_width[$i]) $t_width[$i]=$tt_width[$i]+2*margin+2;
@@ -280,15 +268,12 @@ function invoice_data($x,$y,$width,$font_size,$margin)
     if ($invoice['content']) foreach ($invoice['content'] as $item) {
 	$t_data[1] = $lp;
 	$t_data[2] = iconv("UTF-8","ISO-8859-2",$item['description']);
-	$t_data[3] = $item['pkwiu'];
+	$t_data[3] = $item['prodid'];
 	$t_data[4] = $item['content'];
 	$t_data[5] = $item['count'];
 	$t_data[6] = iconv("UTF-8","ISO-8859-2",moneyf($item['basevalue']));
 	$t_data[7] = iconv("UTF-8","ISO-8859-2",moneyf($item['totalbase']));
-	if ($item['taxvalue']) 
-	    $t_data[8] = $item['taxvalue']." %";
-	else
-	    $t_data[8] = iconv("UTF-8","ISO-8859-2",trans('Tax-free'));
+	$t_data[8] = iconv("UTF-8","ISO-8859-2",$item['taxlabel']);
 	$t_data[9] = iconv("UTF-8","ISO-8859-2",moneyf($item['totaltax']));
 	$t_data[10] = iconv("UTF-8","ISO-8859-2",moneyf($item['total']));
 	
@@ -319,7 +304,7 @@ function invoice_data($x,$y,$width,$font_size,$margin)
     if ($invoice['taxest']) foreach ($invoice['taxest'] as $item) 
     {
 	$t_data[7] = iconv("UTF-8","ISO-8859-2",moneyf($item['base']));
-	$t_data[8] = $item['taxvalue']." %";
+	$t_data[8] = iconv("UTF-8","ISO-8859-2",$item['taxlabel']);
 	$t_data[9] = iconv("UTF-8","ISO-8859-2",moneyf($item['tax']));
 	$t_data[10] = iconv("UTF-8","ISO-8859-2",moneyf($item['total']));
 	$y = invoice_short_data_row($x,$y,$width,$font_size,$margin,$t_data,$t_width,$t_justify);
@@ -338,18 +323,18 @@ function invoice_to_pay($x,$y)
 
 function invoice_expositor ($x,$y) 
 {
-    global $pdf, $_CONFIG;
-    $y = $y - text_align_left($x,$y,10,iconv("UTF-8","ISO-8859-2",trans('Expositor:')).' '.iconv("UTF-8","ISO-8859-2",$_CONFIG['invoices']['default_author']));
+    global $pdf, $CONFIG;
+    $y = $y - text_align_left($x,$y,10,iconv("UTF-8","ISO-8859-2",trans('Expositor:')).' '.iconv("UTF-8","ISO-8859-2",$CONFIG['invoices']['default_author']));
     return $y;
 }
 
 function invoice_footnote($x, $y, $width, $font_size) 
 {
-    global $pdf, $_CONFIG;
-    if ($_CONFIG['invoices']['footer']) {
+    global $pdf, $CONFIG;
+    if ($CONFIG['invoices']['footer']) {
 	$y = $y - $pdf->getFontHeight($font_size);
 	$y = $y - text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Notes:')).'</b>');
-	$tmp = iconv("UTF-8","ISO-8859-2",$_CONFIG['invoices']['footer']);
+	$tmp = iconv("UTF-8","ISO-8859-2",$CONFIG['invoices']['footer']);
         $tmp = explode("\n",$tmp);
 	foreach ($tmp as $line) $y = text_wrap($x,$y,$width,$font_size,$line,"full");
     }
@@ -357,8 +342,8 @@ function invoice_footnote($x, $y, $width, $font_size)
 
 function invoice_body() 
 {
-    global $invoice,$pdf,$id,$_CONFIG,$_MODULES_DIR;
-    switch ($_CONFIG['invoices']['template_file']) {
+    global $invoice,$pdf,$id,$CONFIG,$_MODULES_DIR;
+    switch ($CONFIG['invoices']['template_file']) {
 	case "standard":
 	    $top=800;
 	    invoice_dates(500,800);    
@@ -395,7 +380,7 @@ function invoice_body()
 	    invoice_simple_form_fill(14,3,0.4);
 	    break;
 	default:
-	    require($_MODULES_DIR.'/'.$_CONFIG['invoices']['template_file']);
+	    require($_MODULES_DIR.'/'.$CONFIG['invoices']['template_file']);
     }
     if (!($invoice['last'])) $id=$pdf->newPage(1,$id,'after');
 }
@@ -426,7 +411,6 @@ $id = $pdf->getFirstPageId();
 
 $invoice = $LMS->GetInvoiceContent($_GET['id']);
 
-$layout['pagetitle'] = iconv("UTF-8","ISO-8859-2",trans('Invoice No. $0', $ntempl));
 $invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
 $invoice['last'] = TRUE;
 $type = trans('ORIGINAL');
