@@ -1,5 +1,5 @@
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -19,19 +19,18 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: ethers.c,v 1.18.2.1 2005/05/13 20:09:48 alec Exp $
+ *  $Id: ethers.c,v 1.22 2005/09/16 07:32:06 alec Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
 #include <syslog.h>
 #include <string.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 #include "lmsd.h"
 #include "ethers.h"
 
-unsigned long inet_addr(unsigned char*);
-char * inet_ntoa(unsigned long);
-
 void reload(GLOBAL *g, struct ethers_module *fm)
 {
 	FILE *fh;
@@ -43,7 +42,7 @@ void reload(GLOBAL *g, struct ethers_module *fm)
 	char *netname = strdup(netnames);
     
 	struct group *ugps = (struct group *) malloc(sizeof(struct group));
-	char *groupnames = strdup(fm->usergroups);	
+	char *groupnames = strdup(fm->customergroups);	
 	char *groupname = strdup(groupnames);
 
 	while( n>1 )
@@ -86,7 +85,7 @@ void reload(GLOBAL *g, struct ethers_module *fm)
 
 		if( strlen(groupname) )
 		{
-			res = g->db_pquery(g->conn, "SELECT name, id FROM usergroups WHERE UPPER(name)=UPPER('?')", groupname);
+			res = g->db_pquery(g->conn, "SELECT name, id FROM customergroups WHERE UPPER(name)=UPPER('?')", groupname);
 
 			if( g->db_nrows(res) )
 			{
@@ -119,10 +118,10 @@ void reload(GLOBAL *g, struct ethers_module *fm)
 			m = gc;
 			if(gc && ownerid)
 			{
-				res1 = g->db_pquery(g->conn, "SELECT usergroupid FROM userassignments WHERE userid=?", g->db_get_data(res,i,"ownerid"));
+				res1 = g->db_pquery(g->conn, "SELECT customergroupid FROM customerassignments WHERE customerid=?", g->db_get_data(res,i,"ownerid"));
 				for(k=0; k<g->db_nrows(res1); k++)
 				{
-					int groupid = atoi(g->db_get_data(res1, k, "usergroupid"));
+					int groupid = atoi(g->db_get_data(res1, k, "customergroupid"));
 					for(m=0; m<gc; m++) 
 						if(ugps[m].id==groupid) 
 							break;
@@ -134,10 +133,10 @@ void reload(GLOBAL *g, struct ethers_module *fm)
 			if( j!=nc && (gc==0 || m!=gc) )
 			{
 				if( atoi(g->db_get_data(res,i,"access")) )
-					fprintf(fh, "%s\t%s\n", g->db_get_data(res,i,"mac"), inet_ntoa(inet));
+					fprintf(fh, "%s\t%s\n", g->db_get_data(res,i,"mac"), inet_ntoa(inet_makeaddr(htonl(inet), 0)));
 				else
 					if( fm->dummy_macs )
-						fprintf(fh, "00:00:00:00:00:00\t%s\n", inet_ntoa(inet));	
+						fprintf(fh, "00:00:00:00:00:00\t%s\n", inet_ntoa(inet_makeaddr(htonl(inet), 0)));	
 			}
 		}
 
@@ -160,7 +159,7 @@ void reload(GLOBAL *g, struct ethers_module *fm)
 	free(ugps);
 	
 	free(fm->networks);
-	free(fm->usergroups);
+	free(fm->customergroups);
 	free(fm->file);
 	free(fm->command);
 }
@@ -182,7 +181,7 @@ struct ethers_module * init(GLOBAL *g, MODULE *m)
 	fm->command = strdup(g->config_getstring(fm->base.ini, fm->base.instance, "command", "arp -f /etc/ethers"));
 	fm->dummy_macs = g->config_getbool(fm->base.ini, fm->base.instance, "dummy_macs", 0);
 	fm->networks = strdup(g->config_getstring(fm->base.ini, fm->base.instance, "networks", ""));
-	fm->usergroups = strdup(g->config_getstring(fm->base.ini, fm->base.instance, "usergroups", ""));
+	fm->customergroups = strdup(g->config_getstring(fm->base.ini, fm->base.instance, "customergroups", ""));
 
 #ifdef DEBUG1
 	syslog(LOG_INFO,"DEBUG: [%s/ethers] initialized", fm->base.instance);
