@@ -1,5 +1,5 @@
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: ggnotify.c,v 1.13.2.1 2005/05/13 20:09:49 alec Exp $
+ *  $Id: ggnotify.c,v 1.19 2005/09/29 07:35:50 alec Exp $
  */
 
 #include <stdio.h>
@@ -39,6 +39,13 @@
 
 #define BUFFERSIZE 1024
 
+unsigned char * ftoa(double i)
+{
+	static char string[12];
+	sprintf(string, "%.2f", i);
+	return string;
+}
+
 unsigned char * load_file(unsigned char *name)
 {
 	unsigned char *ret = NULL;
@@ -81,7 +88,8 @@ void reload(GLOBAL *g, struct ggnotify_module *n)
 {
 	QueryHandle *res, *result;
 	unsigned char *message = 0;
-	int i, j, balance;
+	int i, j;
+	double balance;
 	struct gg_session *sess;
 	struct gg_login_params p;
 
@@ -101,15 +109,15 @@ void reload(GLOBAL *g, struct ggnotify_module *n)
 		syslog(LOG_INFO, "DEBUG: [%s/ggnotify] Connected to Gadu-Gadu server.",n->base.instance);
 #endif
 	
-		res = g->db_query(g->conn, "SELECT users.id AS id, gguin, name, lastname, SUM((type * -2 +7) * cash.value) AS balance FROM users LEFT JOIN cash ON users.id = cash.userid AND (cash.type = 3 OR cash.type = 4) WHERE deleted = 0 GROUP BY users.id, gguin, name, lastname");
+		res = g->db_query(g->conn, "SELECT customers.id AS id, im, pin, name, lastname, SUM(cash.value) AS balance FROM customers LEFT JOIN cash ON customers.id = cash.customerid WHERE deleted = 0 GROUP BY customers.id, im, pin, name, lastname");
 
 		if( g->db_nrows(res) )
 		{
 			for(i=0; i<g->db_nrows(res); i++)
 			{
-				if( atoi(g->db_get_data(res,i,"gguin")) )
+				if( atoi(g->db_get_data(res,i,"im")) )
 				{
-					balance = atoi(g->db_get_data(res,i,"balance"));
+					balance = atof(g->db_get_data(res,i,"balance"));
 			
 					if( balance < n->limit )
 					{
@@ -123,7 +131,7 @@ void reload(GLOBAL *g, struct ggnotify_module *n)
 								
 								last_ten = strdup("");
 								
-								result = g->db_pquery(g->conn, "SELECT CASE WHEN type=4 THEN value*-1 ELSE value END AS value, comment, time FROM cash WHERE userid = ? ORDER BY time DESC LIMIT 10", g->db_get_data(res,i,"id"));
+								result = g->db_pquery(g->conn, "SELECT value, comment, time FROM cash WHERE customerid = ? ORDER BY time DESC LIMIT 10", g->db_get_data(res,i,"id"));
 							
 								for(j=0; j<g->db_nrows(result); j++)
 								{
@@ -148,6 +156,9 @@ void reload(GLOBAL *g, struct ggnotify_module *n)
 							}
 						
 							g->str_replace(&message, "%saldo", g->db_get_data(res,i,"balance"));
+							g->str_replace(&message, "%B", g->db_get_data(res,i,"balance"));
+							g->str_replace(&message, "%b", balance < 0 ? ftoa(balance * -1) : g->db_get_data(res,i,"balance"));
+							g->str_replace(&message, "%pin", g->db_get_data(res,i,"pin"));
 							g->str_replace(&message, "%name", g->db_get_data(res,i,"name"));
 							g->str_replace(&message, "%lastname", g->db_get_data(res,i,"lastname"));
 
@@ -169,7 +180,7 @@ void reload(GLOBAL *g, struct ggnotify_module *n)
 									gg_free_session(sess);
 								}
 							} else {
-								if (gg_send_message(sess, GG_CLASS_MSG, atoi(g->db_get_data(res,i,"gguin")), message) == -1)
+								if (gg_send_message(sess, GG_CLASS_MSG, atoi(g->db_get_data(res,i,"im")), message) == -1)
 								{
 									syslog(LOG_INFO, "DEBUG: [%s/ggnotify] Connection broken..",n->base.instance);								
 									gg_free_session(sess);
