@@ -1,5 +1,5 @@
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -19,20 +19,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: hostfile.c,v 1.33.2.1 2005/05/13 20:09:49 alec Exp $
+ *  $Id: hostfile.c,v 1.37 2005/09/16 18:52:16 alec Exp $
  */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <syslog.h>
 #include <string.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 #include "lmsd.h"
 #include "hostfile.h"
 
-unsigned long inet_addr(char *);
-unsigned char * inet_ntoa(unsigned long);
-
 void reload(GLOBAL *g, struct hostfile_module *hm)
 {
 	FILE *fh;
@@ -45,7 +44,7 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 	char *netname = strdup(netnames);
 	
 	struct group *ugps = (struct group *) malloc(sizeof(struct group));
-	char *groupnames = strdup(hm->usergroups);	
+	char *groupnames = strdup(hm->customergroups);	
 	char *groupname = strdup(groupnames);
 
 	while( n>1 )
@@ -101,7 +100,7 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 
 		if( strlen(groupname) )
 		{
-			res = g->db_pquery(g->conn, "SELECT name, id FROM usergroups WHERE UPPER(name)=UPPER('?')",groupname);
+			res = g->db_pquery(g->conn, "SELECT name, id FROM customergroups WHERE UPPER(name)=UPPER('?')",groupname);
 
 			if( g->db_nrows(res) )
 			{
@@ -117,7 +116,7 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 
 	if(!gc)
 	{
-		res = g->db_query(g->conn, "SELECT name, id FROM usergroups ORDER BY name");
+		res = g->db_query(g->conn, "SELECT name, id FROM customergroups ORDER BY name");
 
 		for(gc=0; gc<g->db_nrows(res); gc++)
 		{
@@ -166,12 +165,12 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 								
 				// groups test
 				m = gc;
-				if( strlen(hm->usergroups)>0 && ownerid )
+				if( strlen(hm->customergroups)>0 && ownerid )
 				{
-					res1 = g->db_pquery(g->conn, "SELECT usergroupid FROM userassignments WHERE userid=?", g->db_get_data(res,i,"ownerid"));
+					res1 = g->db_pquery(g->conn, "SELECT customergroupid FROM customerassignments WHERE customerid=?", g->db_get_data(res,i,"ownerid"));
 					for(k=0; k<g->db_nrows(res1); k++)
 					{
-						int groupid = atoi(g->db_get_data(res1, k, "usergroupid"));
+						int groupid = atoi(g->db_get_data(res1, k, "customergroupid"));
 						for(m=0; m<gc; m++) 
 							if( ugps[m].id==groupid ) 
 								break;
@@ -180,7 +179,7 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 					g->db_free(&res1);
 				}
 				
-				if( j!=nc && (strlen(hm->usergroups)==0 || m!=gc) )
+				if( j!=nc && (strlen(hm->customergroups)==0 || m!=gc) )
 				{
 					unsigned char *pattern, *s;
 
@@ -197,8 +196,8 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 					g->str_replace(&s, "%dns2", nets[j].dns2);
 					g->str_replace(&s, "%dns", nets[j].dns);
 					g->str_replace(&s, "%wins", nets[j].wins);
-					g->str_replace(&s, "%mask", inet_ntoa(nets[j].mask));
-					g->str_replace(&s, "%addr", inet_ntoa(nets[j].address));
+					g->str_replace(&s, "%mask", inet_ntoa(inet_makeaddr(htonl(nets[j].mask),0)));
+					g->str_replace(&s, "%addr", inet_ntoa(inet_makeaddr(htonl(nets[j].address),0)));
 					g->str_replace(&s, "%info", info);
 					g->str_replace(&s, "%ipub", ip_pub);
 					g->str_replace(&s, "%id", id);
@@ -252,7 +251,7 @@ void reload(GLOBAL *g, struct hostfile_module *hm)
 	free(hm->file);
 	free(hm->command);
 	free(hm->networks);
-	free(hm->usergroups);
+	free(hm->customergroups);
 }
 
 struct hostfile_module * init(GLOBAL *g, MODULE *m)
@@ -278,7 +277,7 @@ struct hostfile_module * init(GLOBAL *g, MODULE *m)
 	hm->file = strdup(g->config_getstring(hm->base.ini, hm->base.instance, "file", "/tmp/hostfile"));
 	hm->command = strdup(g->config_getstring(hm->base.ini, hm->base.instance, "command", ""));
 	hm->networks = strdup(g->config_getstring(hm->base.ini, hm->base.instance, "networks", ""));
-	hm->usergroups = strdup(g->config_getstring(hm->base.ini, hm->base.instance, "usergroups", ""));
+	hm->customergroups = strdup(g->config_getstring(hm->base.ini, hm->base.instance, "customergroups", ""));
 #ifdef DEBUG1
 	syslog(LOG_INFO,"DEBUG: [%s/hostfile] initialized", hm->base.instance);
 #endif
