@@ -1,5 +1,5 @@
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: notify.c,v 1.16.2.1 2005/05/13 20:09:49 alec Exp $
+ *  $Id: notify.c,v 1.21 2005/09/29 07:35:50 alec Exp $
  */
 
 #include <stdio.h>
@@ -37,6 +37,13 @@
 
 #define BUFFERSIZE 1024
 
+unsigned char * ftoa(double i)
+{
+	static char string[12];
+	sprintf(string, "%.2f", i);
+	return string;
+}
+
 unsigned char * load_file(unsigned char *name)
 {
 	unsigned char *ret = NULL;
@@ -101,15 +108,16 @@ void reload(GLOBAL *g, struct notify_module *n)
 	QueryHandle *res, *result;
 	unsigned char *mailfile = 0;
 	unsigned char *command;
-	int i, j, balance;
+	int i, j; 
+	double balance;
 
-	res = g->db_query(g->conn, "SELECT users.id AS id, email, name, lastname, SUM((type * -2 +7) * cash.value) AS balance FROM users LEFT JOIN cash ON users.id = cash.userid AND (cash.type = 3 OR cash.type = 4) WHERE deleted = 0 AND email!='' GROUP BY users.id, name, lastname, email");
+	res = g->db_query(g->conn, "SELECT customers.id AS id, email, pin, name, lastname, SUM(cash.value) AS balance FROM customers LEFT JOIN cash ON customers.id = cash.customerid WHERE deleted = 0 AND email!='' GROUP BY customers.id, name, lastname, email, pin");
 	
 	if( g->db_nrows(res) )
 	{
 		for(i=0; i<g->db_nrows(res); i++) 
 		{
-			balance = atoi(g->db_get_data(res,i,"balance"));
+			balance = atof(g->db_get_data(res,i,"balance"));
 			
 			if( balance < n->limit ) 
 			{
@@ -123,7 +131,7 @@ void reload(GLOBAL *g, struct notify_module *n)
 						unsigned char *date, *value, *comment, *temp, *temp2;
 						unsigned char *last_ten = strdup("");
 							
-						result = g->db_pquery(g->conn, "SELECT comment, time, CASE WHEN type=4 THEN value*-1 ELSE value END AS value FROM cash WHERE userid = ? ORDER BY time DESC LIMIT 10", g->db_get_data(res,i,"id"));
+						result = g->db_pquery(g->conn, "SELECT comment, time, value FROM cash WHERE customerid = ? ORDER BY time DESC LIMIT 10", g->db_get_data(res,i,"id"));
 						
 						for(j=0; j<g->db_nrows(result); j++) 
 						{
@@ -149,6 +157,9 @@ void reload(GLOBAL *g, struct notify_module *n)
 					}
 					
 					g->str_replace(&mailfile, "%saldo", g->db_get_data(res,i,"balance"));
+					g->str_replace(&mailfile, "%B", g->db_get_data(res,i,"balance"));
+					g->str_replace(&mailfile, "%b", balance < 0 ? ftoa(balance * -1) : g->db_get_data(res,i,"balance"));
+					g->str_replace(&mailfile, "%pin", g->db_get_data(res,i,"pin"));
 					g->str_replace(&mailfile, "%name", g->db_get_data(res,i,"name"));
 					g->str_replace(&mailfile, "%lastname", g->db_get_data(res,i,"lastname"));
 				
