@@ -1,5 +1,5 @@
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: payments.c,v 1.38.2.1 2005/05/13 20:09:50 alec Exp $
+ *  $Id: payments.c,v 1.50 2005/10/05 14:56:29 alec Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -62,32 +62,38 @@ unsigned char * get_period(struct tm *today, int period, int up_payments)
 	
 	if( up_payments )
 		switch(period) {
-			case 0:	//week
-				t->tm_mday += 7;
+			case WEEKLY:
+				t->tm_mday += 6;
 				break;
-			case 1:	//month
+			case MONTHLY:
 				t->tm_mon += 1;
+				t->tm_mday -= 1; 
 				break;
-			case 2: //quarter
+			case QUARTERLY:
 				t->tm_mon += 3;
+				t->tm_mday -= 1;
 				break;
-			case 3:	//year
+			case YEARLY:
 				t->tm_mon += 12;
+				t->tm_mday -= 1; 
 				break;
 		}
 	else
 		switch(period) {
-			case 0:	//week
-				t->tm_mday -= 7;
+			case WEEKLY:
+				t->tm_mday -= 6;
 				break;		
-			case 1:	//month
+			case MONTHLY:
 				t->tm_mon -= 1;
+				t->tm_mday += 1;
 				break;
-			case 2: //quarter
+			case QUARTERLY:
 				t->tm_mon -= 3;
+				t->tm_mday += 1;
 				break;
-			case 3:	//year
+			case YEARLY:
 				t->tm_mon -= 12;
+				t->tm_mday += 1;
 				break;
 		}
 
@@ -96,13 +102,20 @@ unsigned char * get_period(struct tm *today, int period, int up_payments)
 	strftime(to, 11, "%Y/%m/%d", localtime(&old_time));
 	strftime(from, 11, "%Y/%m/%d", localtime(&new_time));
 
-	result = (unsigned char *) malloc(strlen(from)+strlen(to)+3);
+	if(period != DAILY)
+	{
+		result = (unsigned char *) malloc(strlen(from)+strlen(to)+3);
 
-	if( up_payments )
-		sprintf(result, "%s-%s", to, from);
+		if( up_payments )
+			sprintf(result, "%s-%s", to, from);
+		else
+			sprintf(result, "%s-%s", from, to);
+	}
 	else
-		sprintf(result, "%s-%s", from, to);
-		
+	{
+		result = strdup(to);
+	}
+	
 	today = localtime(&old_time);
 	
 	return result;
@@ -112,9 +125,9 @@ void reload(GLOBAL *g, struct payments_module *p)
 {
 	QueryHandle *res, *result, *sres;
 	unsigned char *insert;
-	unsigned char *w_period, *m_period, *q_period, *y_period, *value, *taxvalue;
-	unsigned char *description;
-	int i, invoiceid=0, last_userid=0, number=0, exec=0, suspended=0, itemid=0;
+	unsigned char *d_period, *w_period, *m_period, *q_period, *y_period, *value, *taxid;
+	unsigned char *description, *invoiceid;
+	int i, docid=0, last_customerid=0, number=0, exec=0, suspended=0, itemid=0;
 
 	time_t t;
 	struct tm *tt;
@@ -148,39 +161,70 @@ void reload(GLOBAL *g, struct payments_module *p)
 			break;
 	}
 
-	y_period = get_period(tt, 3, p->up_payments);
-	q_period = get_period(tt, 2, p->up_payments);
-	m_period = get_period(tt, 1, p->up_payments);
- 	w_period = get_period(tt, 0, p->up_payments);
+	y_period = get_period(tt, YEARLY, p->up_payments);
+	q_period = get_period(tt, QUARTERLY, p->up_payments);
+	m_period = get_period(tt, MONTHLY, p->up_payments);
+ 	w_period = get_period(tt, WEEKLY, p->up_payments);
+	d_period = get_period(tt, DAILY, p->up_payments);
 
 	// and setting appropriate time limits to get current invoice number
 	tt->tm_sec = 0;
 	tt->tm_min = 0;
 	tt->tm_hour = 0;
 	tt->tm_mday = 1;
+	tt->tm_mon = atoi(month)-1;
 	tt->tm_year = atoi(year)-1900;
 
-	if(p->monthly_num)
+	switch(p->num_period)
 	{
-		tt->tm_mon = atoi(month)-1; // current month
-		strftime(start,	sizeof(start), "%s", tt);
-		tt->tm_mon++; // next month
-		strftime(end, sizeof(end), "%s", tt);
+		case DAILY:
+			tt->tm_mday = atoi(monthday); // current day
+		break;
+		case WEEKLY:
+			tt->tm_mday = atoi(monthday) - atoi(weekday) + 1; // last Monday
+		break;
+		case MONTHLY:
+		break;
+		case QUARTERLY:
+			switch(tt->tm_mon)
+			{
+				case 0: case 1: case 2: tt->tm_mon = 0; break;
+				case 3: case 4: case 5: tt->tm_mon = 3; break;
+				case 6: case 7: case 8: tt->tm_mon = 6; break;
+				case 9: case 10: case 11: tt->tm_mon = 9; break;
+			}
+		break;
+		default: //YEARLY
+			tt->tm_mon = 0; // January
+		break;
 	}
-	else
+	strftime(start,	sizeof(start), "%s", tt);
+	switch(p->num_period)
 	{
-		tt->tm_mon = 0; // January
-		strftime(start,	sizeof(start), "%s", tt);
-		tt->tm_year++; // next year
-		strftime(end, sizeof(end), "%s", tt);
+		case DAILY:
+			tt->tm_mday++; // tomorrow
+		break;
+		case WEEKLY:
+			tt->tm_wday += 7; // start of next week
+		break;
+		case MONTHLY:
+			tt->tm_mon++; // next month
+		break;
+		case QUARTERLY:
+			tt->tm_mon += 3; // first month of next quarter
+		break;
+		default: //YEARLY
+			tt->tm_year++; // next year
+		break;
 	}
+	strftime(end, sizeof(end), "%s", tt);
 
 	/****** main payments *******/
-	if( (res = g->db_pquery(g->conn, "SELECT * FROM payments WHERE value <> 0 AND ((period=0 AND at=?) OR (period=1 AND at=?) OR (period=2 AND at=?) OR (period=3 AND at=?))", weekday, monthday, quarterday, yearday))!= NULL )
+	if( (res = g->db_pquery(g->conn, "SELECT * FROM payments WHERE value <> 0 AND (period="_DAILY_" OR (period="_WEEKLY_" AND at=?) OR (period="_MONTHLY_" AND at=?) OR (period="_QUARTERLY_" AND at=?) OR (period="_YEARLY_" AND at=?))", weekday, monthday, quarterday, yearday))!= NULL )
 	{
 		for(i=0; i<g->db_nrows(res); i++) 
 		{
-			exec = (g->db_pexec(g->conn, "INSERT INTO cash (time, type, value, userid, comment, invoiceid) VALUES (%NOW%, 2, ?, 0, '? / ?', 0)",
+			exec = (g->db_pexec(g->conn, "INSERT INTO cash (time, value, customerid, comment, docid) VALUES (%NOW%, ? * -1, 0, '? / ?', 0)",
 					g->db_get_data(res,i,"value"),
 					g->db_get_data(res,i,"name"),
 					g->db_get_data(res,i,"creditor")
@@ -193,124 +237,128 @@ void reload(GLOBAL *g, struct payments_module *p)
 	} else 
 		syslog(LOG_ERR, "[%s/payments] Unable to read 'payments' table",p->base.instance);
 		
-	/****** user payments *******/
-	// first get max invoiceid for present year
-	if( (res = g->db_pquery(g->conn, "SELECT MAX(number) AS number FROM invoices WHERE cdate >= ? AND cdate < ?", start, end))!= NULL ) 
+	/****** customer payments *******/
+	// first get next invoiceid
+	if( (res = g->db_pquery(g->conn, "SELECT MAX(number) AS number FROM documents WHERE cdate >= ? AND cdate < ? AND numberplanid = ? AND type = 1", start, end, p->numberplanid))!= NULL ) 
 	{
   		if( g->db_nrows(res) )
 			number = atoi(g->db_get_data(res,0,"number"));
 		g->db_free(&res);
 
 		// payments accounting and invoices writing
-		res = g->db_pquery(g->conn, "SELECT assignments.id AS id, tariffid, userid, period, at, ROUND(CASE discount WHEN 0 THEN value ELSE value-value*discount/100 END, 2) AS value, taxvalue, suspended, pkwiu, uprate, downrate, tariffs.name AS tariff, invoice, UPPER(lastname) AS lastname, users.name AS name, address, zip, city, nip, pesel, phone1 AS phone FROM assignments, tariffs, users WHERE tariffs.id = tariffid AND userid = users.id AND status = 3 AND deleted = 0 AND value <> 0 AND ((period = 0 AND at = ?) OR (period = 1 AND at = ?) OR (period = 2 AND at = ?) OR (period = 3 AND at = ?)) AND (datefrom <= %NOW% OR datefrom = 0) AND (dateto >= %NOW% OR dateto = 0) ORDER BY userid, invoice DESC, value DESC", weekday, monthday, quarterday, yearday);
+		res = g->db_pquery(g->conn, "\
+			SELECT assignments.id AS id, tariffid, customerid, period, at, taxid, suspended, prodid, uprate, downrate, \
+			    ROUND(CASE discount WHEN 0 THEN value ELSE value-value*discount/100 END, 2) AS value, \
+			    tariffs.name AS tariff, invoice, UPPER(lastname) AS lastname, customers.name AS name, address, zip, city, ten, ssn \
+			FROM assignments, tariffs, customers \
+			WHERE tariffs.id = tariffid AND customerid = customers.id AND status = 3 AND deleted = 0 AND value <> 0 \
+			    AND (period="_DAILY_" OR (period="_WEEKLY_" AND at=?) OR (period="_MONTHLY_" AND at=?) OR (period="_QUARTERLY_" AND at=?) OR (period="_YEARLY_" AND at=?)) \
+			    AND (datefrom <= %NOW% OR datefrom = 0) AND (dateto >= %NOW% OR dateto = 0) \
+			ORDER BY customerid, invoice DESC, value DESC", weekday, monthday, quarterday, yearday);
 		
 		for(i=0; i<g->db_nrows(res); i++) 
 		{
-			int uid = atoi(g->db_get_data(res,i,"userid"));
+			int uid = atoi(g->db_get_data(res,i,"customerid"));
 			int s_state = atoi(g->db_get_data(res,i,"suspended"));
 			double val = atof(g->db_get_data(res,i,"value"));
 			
 			// assignments suspending check
 			if( suspended != uid )
 			{
-				sres = g->db_pquery(g->conn, "SELECT 1 FROM assignments, users WHERE userid = users.id AND tariffid = 0 AND (datefrom <= %NOW% OR datefrom = 0) AND (dateto >= %NOW% OR dateto = 0) AND userid = ?", g->db_get_data(res,i,"userid"));
+				sres = g->db_pquery(g->conn, "SELECT 1 FROM assignments, customers WHERE customerid = customers.id AND tariffid = 0 AND (datefrom <= %NOW% OR datefrom = 0) AND (dateto >= %NOW% OR dateto = 0) AND customerid = ?", g->db_get_data(res,i,"customerid"));
 				if( g->db_nrows(sres) ) 
 				{
 					suspended = uid;
 				}
 				g->db_free(&sres);
 			}
-    			
+
 			if( suspended == uid || s_state )
 				val = val * p->suspension_percentage / 100;
 			
 			if( !val )
 				continue;
-			
+
 			value = ftoa(val);
-			taxvalue = g->db_get_data(res,i,"taxvalue");
+			taxid = g->db_get_data(res,i,"taxid");
+
 			// prepare insert to 'cash' table
-			insert = strdup("INSERT INTO cash (time, type, value, taxvalue, userid, comment, invoiceid, itemid) VALUES (%NOW%, 4, %value, %taxvalue, %userid, '?', %invoiceid, %itemid)");
-			g->str_replace(&insert, "%userid", g->db_get_data(res,i,"userid"));
+			insert = strdup("INSERT INTO cash (time, value, taxid, customerid, comment, docid, itemid) VALUES (%NOW%, %value * -1, %taxid, %customerid, '?', %invoiceid, %itemid)");
+			g->str_replace(&insert, "%customerid", g->db_get_data(res,i,"customerid"));
 			g->str_replace(&insert, "%value", value);
 			description = strdup(p->comment);
 			switch( atoi(g->db_get_data(res,i,"period")) ) 
 			{
-				case 0: g->str_replace(&description, "%period", w_period); break;
-				case 1: g->str_replace(&description, "%period", m_period); break;
-				case 2: g->str_replace(&description, "%period", q_period); break;
-				case 3: g->str_replace(&description, "%period", y_period); break;
+				case DAILY: g->str_replace(&description, "%period", d_period); break;
+				case WEEKLY: g->str_replace(&description, "%period", w_period); break;
+				case MONTHLY: g->str_replace(&description, "%period", m_period); break;
+				case QUARTERLY: g->str_replace(&description, "%period", q_period); break;
+				case YEARLY: g->str_replace(&description, "%period", y_period); break;
 			}
 			g->str_replace(&description, "%tariff", g->db_get_data(res,i,"tariff"));
-			if( strlen(taxvalue) )
-				g->str_replace(&insert, "%taxvalue", taxvalue);
-			else
-				g->str_replace(&insert, "%taxvalue", "NULL");
+			g->str_replace(&insert, "%taxid", taxid);
 			
 			if( atoi(g->db_get_data(res,i,"invoice")) ) 
 			{
-				if( last_userid != uid ) 
+				if( last_customerid != uid ) 
 				{
 					// prepare insert to 'invoices' table
-					g->db_pexec(g->conn, "INSERT INTO invoices (number, customerid, name, address, zip, city, phone, nip, pesel, cdate, paytime, paytype, finished) VALUES (?, ?, '? ?', '?', '?', '?', '?', '?', '?', %NOW%, ?, '?', 1 )",
+					g->db_pexec(g->conn, "INSERT INTO documents (number, numberplanid, type, customerid, name, address, zip, city, ten, ssn, cdate, paytime, paytype) VALUES (?, ?, 1, ?, '? ?', '?', '?', '?', '?', '?', %NOW%, ?, '?')",
 						itoa(++number),
-						g->db_get_data(res,i,"userid"),
+						p->numberplanid,
+						g->db_get_data(res,i,"customerid"),
 						g->db_get_data(res,i,"lastname"),
 						g->db_get_data(res,i,"name"),
 						g->db_get_data(res,i,"address"),
 						g->db_get_data(res,i,"zip"),
 						g->db_get_data(res,i,"city"),
-						g->db_get_data(res,i,"phone"),
-						g->db_get_data(res,i,"nip"),
-						g->db_get_data(res,i,"pesel"),
+						g->db_get_data(res,i,"ten"),
+						g->db_get_data(res,i,"ssn"),
 						p->deadline,
 						p->paytype
 					);
-		
+
 					// mae uproszczenie w stosunku do lms-payments
-					result = g->db_query(g->conn, "SELECT MAX(id) AS id FROM invoices");
-					invoiceid = (g->db_nrows(result) ? atoi(g->db_get_data(result,0,"id")) : 0);
+					result = g->db_query(g->conn, "SELECT MAX(id) AS id FROM documents WHERE type = 1");
+					docid = g->db_nrows(result) ? atoi(g->db_get_data(result,0,"id")) : 0;
 					g->db_free(&result);
 					itemid = 0;
 				}
 				
-				result = g->db_pquery(g->conn, "SELECT itemid FROM invoicecontents WHERE tariffid = ? AND invoiceid = ? AND description = '?'", g->db_get_data(res,i,"tariffid"), itoa(invoiceid), description);
+				invoiceid = strdup(itoa(docid));
+				
+				result = g->db_pquery(g->conn, "SELECT itemid FROM invoicecontents WHERE tariffid = ? AND docid = ? AND description = '?' AND value = ?", g->db_get_data(res,i,"tariffid"), invoiceid, description, value);
 
 				if( g->db_nrows(result) ) 
 				{
-					g->db_pexec(g->conn, "UPDATE invoicecontents SET count=count+1 WHERE tariffid = ? AND invoiceid = ? AND description = '?'",
-						g->db_get_data(res,i,"tariffid"),
-						itoa(invoiceid),
-						description
+					g->db_pexec(g->conn, "UPDATE invoicecontents SET count = count+1 WHERE docid = ? AND itemid = ?",
+						invoiceid,
+						g->db_get_data(result,0,"itemid")
 						);
 					
-					exec = g->db_pexec(g->conn, "UPDATE cash SET value=value+? WHERE invoiceid=? AND itemid=?",value, itoa(invoiceid), g->db_get_data(result,0,"itemid"));
+					exec = g->db_pexec(g->conn, "UPDATE cash SET value = value + (? * -1) WHERE docid = ? AND itemid = ?", value, invoiceid, g->db_get_data(result,0,"itemid"));
 				}
 				else 
 				{
-					char * tmp_tax; 
-					if( strlen(taxvalue) )
-						tmp_tax = taxvalue;
-					else
-						tmp_tax = "NULL";
-					
 					itemid++;
-
-					g->db_pexec(g->conn,"INSERT INTO invoicecontents (invoiceid, itemid, value, taxvalue, pkwiu, content, count, description, tariffid) VALUES (?, ?, ?, ?, '?', 'szt.', 1, '?', ?)",
-						itoa(invoiceid),
+					
+					g->db_pexec(g->conn,"INSERT INTO invoicecontents (docid, itemid, value, taxid, prodid, content, count, description, tariffid) VALUES (?, ?, ?, ?, '?', 'szt.', 1, '?', ?)",
+						invoiceid,
 						itoa(itemid),
 						value,
-						tmp_tax,
-						g->db_get_data(res,i,"pkwiu"),
+						taxid,
+						g->db_get_data(res,i,"prodid"),
 						description,
 						g->db_get_data(res,i,"tariffid")
 						);
 					
-					g->str_replace(&insert, "%invoiceid", itoa(invoiceid));
+					g->str_replace(&insert, "%invoiceid", invoiceid);
 					g->str_replace(&insert, "%itemid", itoa(itemid));
 					exec = g->db_pexec(g->conn, insert, description);
 				}
+				
 				g->db_free(&result);
+				free(invoiceid);
 			} 
 			else 
 			{
@@ -319,7 +367,7 @@ void reload(GLOBAL *g, struct payments_module *p)
 				exec = g->db_pexec(g->conn, insert, description) ? 1 : exec;
 			}
 
-			last_userid = uid;
+			last_customerid = uid;
 			free(insert);
 			free(description);
 		}
@@ -329,8 +377,9 @@ void reload(GLOBAL *g, struct payments_module *p)
 		free(q_period);
 		free(m_period);
 		free(w_period);
+		free(d_period);
 #ifdef DEBUG1
-		syslog(LOG_INFO, "DEBUG: [%s/payments] user payments reloaded", p->base.instance);
+		syslog(LOG_INFO, "DEBUG: [%s/payments] customer payments reloaded", p->base.instance);
 #endif
 	}
 	else 
@@ -351,6 +400,7 @@ void reload(GLOBAL *g, struct payments_module *p)
 	free(p->comment);
 	free(p->deadline);
 	free(p->paytype);
+	free(p->numberplanid);
 }
 
 struct payments_module * init(GLOBAL *g, MODULE *m)
@@ -373,28 +423,25 @@ struct payments_module * init(GLOBAL *g, MODULE *m)
 	p->up_payments = g->config_getbool(p->base.ini, p->base.instance, "up_payments", 1);
 	p->expiry_days = g->config_getint(p->base.ini, p->base.instance, "expiry_days", 30);
 	
-	res = g->db_query(g->conn, "SELECT value FROM uiconfig WHERE section='invoices' AND var='monthly_numbering' AND disabled=0");
-	if( g->db_nrows(res) )
-	{
-		char *str = g->db_get_data(res, 0, "value");
-		switch( str[0] )
-		{
-			case 'y': p->monthly_num = 1; break;
-			case 'Y': p->monthly_num = 1; break;
-			case 'T': p->monthly_num = 1; break;
-			case 't': p->monthly_num = 1; break;
-			case '1': p->monthly_num = 1; break;
-		}
-	}
-	g->db_free(&res);
-	p->monthly_num = p->monthly_num ? p->monthly_num : 0;
-
 	res = g->db_query(g->conn, "SELECT value FROM uiconfig WHERE section='finances' AND var='suspension_percentage' AND disabled=0");
 	if( g->db_nrows(res) )
 		p->suspension_percentage = atof(g->db_get_data(res, 0, "value"));
 	else
 		p->suspension_percentage = 0;
 	g->db_free(&res);
+
+	res = g->db_query(g->conn, "SELECT id, period FROM numberplans WHERE doctype=1 AND isdefault=1");
+	if( g->db_nrows(res) )
+	{
+		p->num_period = atoi(g->db_get_data(res, 0, "period"));
+		p->numberplanid = strdup(g->db_get_data(res, 0, "id"));
+	}
+	else
+	{
+		p->num_period = YEARLY;
+		p->numberplanid = strdup("0");
+	}
+	g->db_free(&res);
 	
 #ifdef DEBUG1
 	syslog(LOG_INFO,"DEBUG: [%s/payments] initialized", p->base.instance);
