@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_mysql.class.php,v 1.32.2.1 2005/05/13 20:09:53 alec Exp $
+ *  $Id: LMSDB_driver_mysql.class.php,v 1.34 2005/10/05 10:38:02 alec Exp $
  */
 
 /*
@@ -36,7 +36,10 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function LMSDB_driver_mysql($dbhost, $dbuser, $dbpasswd, $dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.32.2.1 $').')';
+		if(!extension_loaded('mysql'))
+		        die('MySQL extension not loaded!');
+	
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.34 $').')';
 		$this->Connect($dbhost, $dbuser, $dbpasswd, $dbname);
 	}
 	
