@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,19 +21,18 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Session.class.php,v 2.7.2.3 2005/07/08 13:28:06 lukasz Exp $
+ *  $Id: Session.class.php,v 2.11 2005/07/08 13:28:33 lukasz Exp $
  */
 
 class Session {
 
 	var $SID = NULL;			// session unique ID
-	var $_version = '1.6.1 Ishta';		// library version
-	var $_revision = '$Revision: 2.7.2.3 $';	// library revision
+	var $_version = '1.7.4 Wraith';		// library version
+	var $_revision = '$Revision: 2.11 $';	// library revision
 	var $_content = array();		// session content array
 	var $_updated = FALSE;			// indicates that content has
 						// been altered
 	var $DB = NULL;				// database library object
-	var $CONFIG = NULL;			// configuration array
 	var $timeout = 600;			// timeout since session will
 						// be destroyed
 	var $autoupdate = FALSE;		// do automatic update on each
@@ -41,13 +40,12 @@ class Session {
 	var $GCprob = 10;			// probality (in percent) of
 						// garbage collector procedure
 	
-	function Session(&$DB, &$CONFIG)
+	function Session(&$DB, $timeout = 0)
 	{
 		$this->DB =& $DB;
-		$this->CONFIG =& $CONFIG;
 		
-		if(isset($this->CONFIG['phpui']['timeout']))
-			$this->timeout =& $this->CONFIG['phpui']['timeout'];
+		if(isset($timeout) && $timeout != 0)
+			$this->timeout = $timeout;
 		
 		if(! isset($_COOKIE['SID']))
 			$this->_createSession();
