@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accesstable.php,v 1.64.2.2 2005/06/17 07:06:12 alec Exp $
+ *  $Id: accesstable.php,v 1.79 2005/09/07 08:28:31 alec Exp $
  */
 
 unset($access);
@@ -32,19 +32,19 @@ $access['table'][0]['name']		= trans('full access');
 $access['table'][0]['allow_reg']	= '^.*$';
 
 $access['table'][1]['name']		= trans('read only (excluding helpdesk)');
-$access['table'][1]['allow_reg']	= '^((admin|balance|db|net|node|netdev|tariff|payment|user|usergroup|account|alias|domain|config|event)(list|info|view|search|balance|infoshort)|netdevmap|print|eventprint|nodelistshort)$';
+$access['table'][1]['allow_reg']	= '^((user|balance|db|net|node|netdev|tariff|payment|customer|customergroup|account|alias|domain|config|event|taxrate|document|numberplan)(list|info|view|search|balance|infoshort)|netdevmap|print|eventprint|nodelistshort|number)$';
 
 $access['table'][2]['name']		= trans('nodes connection/disconnection');
 $access['table'][2]['allow_reg']	= '^nodeset$';
 
 $access['table'][3]['name']		= trans('finances management');
-$access['table'][3]['allow_reg']	= '^((tariff)(add|info|list|move|edit|delete)|(payment)(add|del|edit|info|list)|(balance|userbalance)(new|add|ok|del|list)|(invoice|invoice(list|new|edit|report|paid))|prepayments|choosecovenants)$';
+$access['table'][3]['allow_reg']	= '^((tariff)(add|info|list|move|edit|delete)|(payment)(add|del|edit|info|list)|(balance|customerbalance)(new|add|ok|del|list)|(receipt|receipt(list|add|edit|del))|(invoice|invoice(list|new|edit|note|report))|number|paid)$';
 
 $access['table'][4]['name']    		= trans('configuration reload');
 $access['table'][4]['allow_reg']    	= '^reload$';
 
 $access['table'][5]['name']		= trans('customers management');
-$access['table'][5]['allow_reg']	= '^(user(add|edit|del|assignments|assignmentsedit|warn)|nodewarn|usergroup(add|edit|delete|move))$';
+$access['table'][5]['allow_reg']	= '^((customer|document)(add|edit|del|assignments|assignmentsedit|warn)|nodewarn|customergroup(add|edit|delete|move))$';
 
 $access['table'][6]['name'] 		= trans('nodes management');
 $access['table'][6]['allow_reg']  	= '^(node(add|scan|del|edit|warn)|choose(mac|ip))$';
@@ -64,8 +64,8 @@ $access['table'][10]['allow_reg']   	= '^(rtsearch|rtqueue(list|info|view)|(rtti
 $access['table'][11]['name']        	= trans('accounts management');
 $access['table'][11]['allow_reg']   	= '^((account|domain|alias)(list|edit|add|del))$';
 
-$access['table'][12]['name']        	= trans('UI configuration');
-$access['table'][12]['allow_reg']   	= '^(config(list|edit|add|del|load))$';
+$access['table'][12]['name']        	= trans('configuration');
+$access['table'][12]['allow_reg']   	= '^((host|config|numberplan|taxrate)(list|edit|add|del|load))$';
 
 $access['table'][13]['name']        	= trans('networks and devices management');
 $access['table'][13]['allow_reg']   	= '^((net|netdev)(info|list|edit|add|del|cmp|map|remap)|choose(mac|ip))$';
@@ -74,16 +74,16 @@ $access['table'][14]['name']        	= trans('timetable management');
 $access['table'][14]['allow_reg']   	= '^(event(list|edit|add|del|info|print|search))$';
 
 $access['table'][15]['name']        	= trans('daemon management and configuration');
-$access['table'][15]['allow_reg']   	= '^((daemonhost|daemoninstance|daemonconfig)(list|edit|add|del|view))$';
+$access['table'][15]['allow_reg']   	= '^((daemoninstance|daemonconfig)(list|edit|add|del|view))$';
 
 $access['table'][253]['name']		= trans('users edition and addition forbidden');
-$access['table'][253]['deny_reg']	= '^(admin(add|del|edit|passwd))$';
+$access['table'][253]['deny_reg']	= '^(user(add|del|edit|passwd))$';
 
 $access['table'][255]['name']		= trans('no access');
 $access['table'][255]['deny_reg']	= '^.*$';
 
 // read user-defined access rights table
-if(isset($_CONFIG['phpui']['custom_accesstable']))
-	@include_once($_LIB_DIR.'/'.$_CONFIG['phpui']['custom_accesstable']);
+if(isset($CONFIG['phpui']['custom_accesstable']))
+	@include_once($_LIB_DIR.'/'.$CONFIG['phpui']['custom_accesstable']);
 
 ?>
