@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,18 +21,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: checkip.php,v 1.20.2.1 2005/05/13 20:09:53 alec Exp $
+ *  $Id: checkip.php,v 1.23 2005/07/07 20:20:49 hunter Exp $
  */
 
 // Checking if connection is from allowed IP
 
-if(isset($_CONFIG['phpui']['allow_from']))
+if(isset($CONFIG['phpui']['allow_from']))
 {
-	// usumy prefix ipv6 jak jest
+	// delete ipv6 prefix if it's present: 
 	
 	$ipaddr = str_replace('::ffff:','',$_SERVER['REMOTE_ADDR']);
 
-	$allowedlist = explode(',',$_CONFIG['phpui']['allow_from']);
+	$allowedlist = explode(',',$CONFIG['phpui']['allow_from']);
+
+	$isin = FALSE;
 
 	foreach($allowedlist as $value)
 	{
