@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: common.php,v 1.80.2.1 2005/05/13 20:09:53 alec Exp $
+ *  $Id: common.php,v 1.88 2005/09/11 13:49:22 hunter Exp $
  */
 
 // Common functions, that making it in class would be nonsense :)
@@ -85,66 +85,6 @@ function execute_program ($program, $args = '')
 	}
 }
 
-function uptime()
-{
-	// Uptime function. Taken afair from PHPSysinfo.
-
-	switch (PHP_OS)
-	{
-		case 'Linux':
-			$fd = fopen('/proc/uptime', 'r');
-			$ar_buf = split(' ', fgets($fd, 4096));
-			fclose($fd);
-			$sys_ticks = trim($ar_buf[0]);
-			$result = uptimef($sys_ticks);
-		break;
-		case 'FreeBSD':
-			$s = explode(' ', bsd_grab_key('kern.boottime'));
-			$a = ereg_replace('{ ', '', $s[3]);
-			$sys_ticks = time() - $a;
-			$result = uptimef($sys_ticks);
-		break;
-		case 'NetBSD':
-			$a = bsd_grab_key('kern.boottime');
-			$sys_ticks = time() - $a;
-			$result = uptimef($sys_ticks);
-		break;
-		case 'OpenBSD':
-			$a = bsd_grab_key('kern.boottime');
-			$sys_ticks = time() - $a;
-			$result = uptimef($sys_ticks);
-		break;
-		case 'WINNT':
-//			dl("php_w32api.dll");
-			if(function_exists('w32api_register_function'))
-			{
-				w32api_register_function('kernel32.dll','GetTickCount','long');
-				$ticks = GetTickCount();
-				$secs  = floor($ticks / 1000);
-				$mins  = floor($secs / 60);
-				$hours = floor($mins / 60);
-				$str = sprintf('You have been using your computer for: %d Milliseconds, or %d Seconds or %d mins or %d hours %d mins.',	$ticks,	$secs, $mins, $hours, $mins - ($hours*60));
-			}else{
-				$result = trans('unknown (no w32api)');
-			}
-		break;
-		default:
-			$result = trans('unknown OS ($0)', PHP_OS);
-		break;
-	}
-
-	return $result;
-}
-
-function redir($url)
-{
-	if($url)
-	{
-		header('Location: '.$url);
-		die;
-	}
-}
-
 function hostname()
 {
 	switch(PHP_OS)
@@ -528,11 +468,6 @@ function r_trim($array)
 	return $array;
 }
 
-function sql_random()
-{
-	return ( rand()/getrandmax() );
-}
-
 // config value testers
 function isboolean($value)
 {
@@ -548,4 +483,41 @@ function moneyf($value)
 	return sprintf($LANGDEFS[$_language]['money_format'],$value);
 }
 
+if (!function_exists('bcmod'))
+{
+    function bcmod( $x, $y )
+    {
+	// how many numbers to take at once? carefull not to exceed (int)
+        $take = 5;   
+	$mod = '';
+        do
+	{
+	    $a = (int)$mod.substr( $x, 0, $take );
+	    $x = substr( $x, $take );
+	    $mod = $a % $y;   
+	}
+	while ( strlen($x) );
+	    return (int)$mod;
+    }
+}					     
+
+function docnumber($number=NULL, $template=NULL, $time=NULL)
+{
+	$number = $number ? $number : 1;
+	$template = $template ? $template : DEFAULT_NUMBER_TEMPLATE;
+	$time = $time ? $time : time();
+	
+	$result = preg_replace('/%(\\d*)N/e', "sprintf('%0\\1d', $number)", $template);
+	return strftime($result, $time);
+}
+
+// our finance round:
+
+function f_round ($value)
+{
+	$value = str_replace(',','.', $value);
+	$value = round ( (float) $value,2);
+
+	return $value;
+}	
 ?>
