@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,20 +21,19 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbencoding.php,v 1.1.2.3 2005/06/01 07:43:46 alec Exp $
+ *  $Id: dbencoding.php,v 1.5 2005/09/22 06:32:59 alec Exp $
  */
 
-if(strtolower($_CONFIG['database']['server_encoding']) != 'unicode')
+if(strtolower($CONFIG['database']['server_encoding']) != 'unicode')
 {
-	switch($_CONFIG['database']['type'])
+	switch($CONFIG['database']['type'])
 	{
 		case 'postgres':
 			$DB->Execute("SET CLIENT_ENCODING TO 'UNICODE'");
 		break;
 		
-		case 'sqlite':
 		case 'mysql':
-			$DB->iconv = $_CONFIG['database']['server_encoding'];
+			$DB->iconv = $CONFIG['database']['server_encoding'];
 			if(!function_exists('iconv'))
 				die('Iconv support is required by \'server_encoding\' option!');
 			if(!iconv($DB->iconv, $DB->iconv, 'test'))
