@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: smarty_addons.php,v 1.34.2.2 2005/05/19 10:37:29 alec Exp $
+ *  $Id: smarty_addons.php,v 1.47 2005/08/04 08:03:05 alec Exp $
  */
 
 // Funkcje dodatkowe, do roszerzenia Smarty.
@@ -29,14 +29,19 @@
 function _smarty_function_sum($args, &$SMARTY)
 {
 	$array = $args['array'];
-	$column = $args['column'];
 	$format = (isset($args['string_format']) ? $args['string_format'] : '%d');
 	$default = (isset($args['default']) ? $args['default'] : 0);
 	if($array)
 		foreach($array as $row)
 			if(is_array($row))
-				$result += $row[$column];
-	return sprintf($format,(isset($result) ? $result : $default));
+				$result += $row[$args['column']];
+
+	$result = isset($result) ? $result : $default;
+
+	if(isset($args['assign']))
+		$SMARTY->assign($args['assign'], $result);
+	else
+		return sprintf($format, $result);
 }
 
 function _smarty_function_sizeof($args, &$SMARTY)
@@ -53,9 +58,9 @@ function _smarty_function_tip($args, &$SMARTY)
 		if(is_array($args))
 			foreach($args as $argid => $argval)
 				$dynpopup = str_replace('$'.$argid, $argval, $dynpopup);
-		$text = "onMouseOver=\"return overlib('<iframe ID=&quot;autoiframe&quot; FRAMEBORDER=0 SCROLLING=NO width=220 height=150 src=&quot;".$dynpopup."&popup=1&quot;></iframe>',HAUTO,VAUTO,OFFSETX,85,OFFSETY,15);\" onMouseOut=\"nd();\"";
+		$text = "onmouseover=\"return overlib('<iframe id=&quot;autoiframe&quot; width=150 height=10 frameborder=0 scrolling=no src=&quot;".$dynpopup."&popup=1&quot;></iframe>',HAUTO,VAUTO,OFFSETX,30,OFFSETY,15".($args['sticky'] ? ',STICKY, MOUSEOFF' : '').");\" onmouseout=\"nd();\"";
 //		global $SESSION;
-//		$text = 'onMouseOver="if(getSeconds() < '.$SESSION->timeout.'){ return overlib(\'<iframe ID=&quot;autoiframe&quot; FRAMEBORDER=0 SCROLLING=NO width=220 height=150 src=&quot;'.$dynpopup.'&quot;></iframe>\',HAUTO,VAUTO,OFFSETX,85,OFFSETY,15); }" onMouseOut="nd();"';
+//		$text = 'onmouseover="if(getSeconds() < '.$SESSION->timeout.'){ return overlib(\'<iframe id=&quot;autoiframe&quot; frameborder=0 scrolling=no width=220 height=150 src=&quot;'.$dynpopup.'&quot;></iframe>\',HAUTO,VAUTO,OFFSETX,85,OFFSETY,15); }" onmouseout="nd();"';
 		return $text;
 	} else {
 	    $text = $args['text'];
@@ -79,10 +84,10 @@ function _smarty_function_tip($args, &$SMARTY)
 	    $text = str_replace("\n",'<BR>',$text);
 	
 	    if($SMARTY->_tpl_vars['error'][$args['trigger']])
-		    $result = ' onMouseOver="return overlib(\'<B><FONT COLOR=RED>'.$error.'</FONT></B>\',HAUTO,VAUTO,OFFSETX,15,OFFSETY,15);" onMouseOut="nd();" ';
+		    $result = ' onmouseover="return overlib(\'<b><font color=red>'.$error.'</font></b>\',HAUTO,VAUTO,OFFSETX,15,OFFSETY,15);" onmouseout="nd();" ';
 	    elseif($args['text'] != '')
-		    $result = 'onMouseOver="return overlib(\''.$text.'\',HAUTO,VAUTO,OFFSETX,15,OFFSETY,15);" onMouseOut="nd();"';
-	    $result .= ($SMARTY->_tpl_vars['error'][$args['trigger']] ? ($args['bold'] ? ' CLASS="ALERTB" ' : ' CLASS="ALERT" ') : ($args['bold'] ? ' CLASS="BOLD" ' : ''));
+		    $result = 'onmouseover="return overlib(\''.$text.'\',HAUTO,VAUTO,OFFSETX,15,OFFSETY,15);" onmouseout="nd();"';
+	    $result .= ($SMARTY->_tpl_vars['error'][$args['trigger']] ? ($args['bold'] ? ' CLASS="alert bold" ' : ' CLASS="alert" ') : ($args['bold'] ? ' CLASS="bold" ' : ''));
 		    return $result;
 	}
 }
@@ -135,9 +140,25 @@ function _smarty_block_translate($args, $content, &$SMARTY)
     return trim($content);
 }
 
+function _smarty_function_bankaccount($args, &$SMARTY)
+{
+	return bankaccount($args['id']);
+}
+
+function _smarty_function_number($args,&$SMARTY)
+{
+	$result = docnumber($args['number'], $args['template'], $args['time']);
+	if(isset($args['assign']))
+		$SMARTY->assign($args['assign'], $result);
+	else
+		return $result;
+}
+
 $SMARTY->register_function('sum','_smarty_function_sum');
 $SMARTY->register_function('size','_smarty_function_sizeof');
 $SMARTY->register_function('tip','_smarty_function_tip');
+$SMARTY->register_function('bankaccount','_smarty_function_bankaccount');
+$SMARTY->register_function('number','_smarty_function_number');
 $SMARTY->register_modifier('to_words','to_words');
 $SMARTY->register_modifier('money_format','moneyf');
 $SMARTY->register_modifier('striphtml','_smarty_modifier_striphtml');
