@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,17 +21,17 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accountdel.php,v 1.4.2.1 2005/05/13 20:10:00 alec Exp $
+ *  $Id: accountdel.php,v 1.6 2005/05/26 13:24:56 alec Exp $
  */
 
 $id = $_GET['id'];
 
 if($id && $_GET['is_sure']=='1')
 {
-	if($LMS->DB->Execute('DELETE FROM passwd WHERE id = ?', array($id)))
+	if($DB->Execute('DELETE FROM passwd WHERE id = ?', array($id)))
 	{	
 		$LMS->SetTS('passwd');
-		if($LMS->DB->Execute('DELETE FROM aliases WHERE accountid = ?', array($id)))
+		if($DB->Execute('DELETE FROM aliases WHERE accountid = ?', array($id)))
 			$LMS->SetTS('aliases');
 	}
 }
