@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: aliasdel.php,v 1.2.2.1 2005/05/13 20:10:01 alec Exp $
+ *  $Id: aliasdel.php,v 1.4 2005/05/26 13:24:56 alec Exp $
  */
 
 $id = $_GET['id'];
 
 if($id && $_GET['is_sure']=='1')
 {
-	$LMS->DB->Execute('DELETE FROM aliases WHERE id = ?', array($id));
+	$DB->Execute('DELETE FROM aliases WHERE id = ?', array($id));
 	$LMS->SetTS('aliases');
 }
 
