@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancedel.php,v 1.7.2.1 2005/05/13 20:10:01 alec Exp $
+ *  $Id: balancedel.php,v 1.9 2005/09/29 07:35:51 alec Exp $
  */
 
-if (sizeof($_POST['marks']))
+if($_GET['id'])
+{
+	$LMS->DelBalance($_GET['id']);
+}
+elseif(sizeof($_POST['marks']))
 {
 	foreach($_POST['marks'] as $markid => $junk)
 		if ($junk)
