@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,18 +21,27 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancenew.php,v 1.25.2.1 2005/05/13 20:10:01 alec Exp $
+ *  $Id: balancenew.php,v 1.29 2005/09/29 07:35:51 alec Exp $
  */
 
+$layout['pagetitle'] = trans('New Balance');
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
-$layout['pagetitle'] = trans('New Balance');
+$last = $DB->GetRow('SELECT cash.id AS id, cash.value AS value, taxes.label AS tax, 
+		    customerid, time, comment, '.$DB->Concat('UPPER(lastname)', "' '", 'name').' AS customername
+		    FROM cash 
+		    LEFT JOIN customers ON (customerid = customers.id)
+		    LEFT JOIN taxes ON (taxid = taxes.id)
+		    ORDER BY cash.id DESC LIMIT 1');
+
+$SMARTY->assign('last',$last);
 $SMARTY->assign('operation',$SESSION->get('addtype'));
 $SMARTY->assign('comment', $SESSION->get('addbc'));
-$SMARTY->assign('taxvalue', $SESSION->get('addbtax'));
+$SMARTY->assign('taxid', $SESSION->get('addbtax'));
 $SMARTY->assign('time', $SESSION->get('addbt'));
 $SMARTY->assign('value', $SESSION->get('addbv'));
-$SMARTY->assign('users',$LMS->GetUserNames());
+$SMARTY->assign('taxeslist', $LMS->GetTaxes());
+$SMARTY->assign('customers',$LMS->GetCustomerNames());
 $SMARTY->display('balancenew.html');
 
 ?>
