@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: daemonconfigdel.php,v 1.1.2.1 2005/05/13 20:10:02 alec Exp $
+ *  $Id: daemonconfigdel.php,v 1.3 2005/05/26 13:24:57 alec Exp $
  */
 
 $id = $_GET['id'];
 
 if($id && $_GET['is_sure']=='1')
 {
-	if($LMS->DB->Execute('DELETE FROM daemonconfig WHERE id = ?', array($id)))
+	if($DB->Execute('DELETE FROM daemonconfig WHERE id = ?', array($id)))
 	{
 		$LMS->SetTS('daemonconfig');
 	}
