@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,29 +21,29 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbview.php,v 1.30.2.1 2005/05/13 20:10:02 alec Exp $
+ *  $Id: dbview.php,v 1.33 2005/05/27 15:59:04 alec Exp $
  */
 
 function DatabaseFetchContent($db,$save=FALSE)
 {
-	global $LMS;
+	global $DB, $CONFIG;
 	
-	if(file_exists($LMS->CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql'))
+	if(file_exists($CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql'))
 	{		
 		$database['content'] = '';
-		if($content = file($LMS->CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql'))
+		if($content = file($CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql'))
 			foreach($content as $value)
 				$database['content'] .= $value;
-		$database['size'] = filesize($LMS->CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql');
+		$database['size'] = filesize($CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql');
 		$database['name'] = $db;
 		list($database['time']) = explode('-',$db);
 		return $database;
 	}
-	elseif((extension_loaded('zlib'))&&(file_exists($LMS->CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz')))
+	elseif((extension_loaded('zlib'))&&(file_exists($CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz')))
 	{
 		if($save==TRUE)
 		{
-			$file=fopen($LMS->CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz',"r"); //tutaj przepisuje plik binarny 
+			$file=fopen($CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz',"r"); //tutaj przepisuje plik binarny 
 			$database = '';
 			while($part = fread($file,8192))
                             	$database .= $part; 
@@ -51,10 +51,10 @@ function DatabaseFetchContent($db,$save=FALSE)
 		else
 		{
 			$database['content'] = '';
-			if($content = gzfile($LMS->CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz'))
+			if($content = gzfile($CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz'))
 				foreach($content as $value)
                         		$database['content'] .= $value;
-                	$database['size'] = filesize($LMS->CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz');
+                	$database['size'] = filesize($CONFIG['directories']['backup_dir'].'/lms-'.$db.'.sql.gz');
                 	$database['name'] = $db;
 			list($database['time']) = explode('-',$db);
 		}
