@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,22 +21,22 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: domaindel.php,v 1.4.2.1 2005/05/13 20:10:02 alec Exp $
+ *  $Id: domaindel.php,v 1.6 2005/05/26 13:24:57 alec Exp $
  */
 
 $id = $_GET['id'];
 
 if($id && $_GET['is_sure']=='1')
 {
-	if($LMS->DB->Execute('DELETE FROM domains WHERE id = ?', array($id)))
+	if($DB->Execute('DELETE FROM domains WHERE id = ?', array($id)))
 	{
 		$LMS->SetTS('domains');
-		if($accounts = $LMS->DB->GetCol('SELECT id FROM passwd WHERE domainid = ?', array($id)))
+		if($accounts = $DB->GetCol('SELECT id FROM passwd WHERE domainid = ?', array($id)))
 		{
 			foreach($accounts as $aid)
-				$LMS->DB->Execute('DELETE FROM aliases WHERE accountid = ?', array($aid));
+				$DB->Execute('DELETE FROM aliases WHERE accountid = ?', array($aid));
 		
-			$LMS->DB->Execute('DELETE FROM passwd WHERE domainid = ?', array($id));
+			$DB->Execute('DELETE FROM passwd WHERE domainid = ?', array($id));
 			$LMS->SetTS('passwd');
 			$LMS->SetTS('aliases');
 		}
