@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,16 +21,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: eventdel.php,v 1.1.2.1 2005/05/13 20:10:03 alec Exp $
+ *  $Id: eventdel.php,v 1.3 2005/05/26 13:24:57 alec Exp $
  */
 
 $id = $_GET['id'];
 
 if($id && $_GET['is_sure']=='1')
 {
-	if($LMS->DB->Execute('DELETE FROM events WHERE id = ?', array($id)))
+	if($DB->Execute('DELETE FROM events WHERE id = ?', array($id)))
 	{	
-		if($LMS->DB->Execute('DELETE FROM eventassignments WHERE eventid = ?', array($id)))
+		if($DB->Execute('DELETE FROM eventassignments WHERE eventid = ?', array($id)))
 		{
 			$LMS->SetTS('eventassignments');
 		}
