@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: genfake.php,v 1.37.2.2 2005/05/20 11:44:40 kondi Exp $
+ *  $Id: genfake.php,v 1.48 2005/07/23 17:21:40 alec Exp $
  */
 
 // Lastnames
@@ -1837,7 +1837,7 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 
 	echo '<B>'.trans('Clearing database...').'</B><BR>';
 	$DB->Execute('DELETE FROM nodes');
-	$DB->Execute('DELETE FROM users');
+	$DB->Execute('DELETE FROM customers');
 	$DB->Execute('DELETE FROM cash');
 	$DB->Execute('DELETE FROM assignments');
 	$DB->Execute('DELETE FROM networks');
@@ -1845,41 +1845,52 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 	$DB->Execute('DELETE FROM payments');	
 	$DB->Execute('DELETE FROM netdevices');
 	$DB->Execute('DELETE FROM netlinks');
+	$DB->Execute('DELETE FROM documents');
+	$DB->Execute('DELETE FROM taxes');
+	$DB->Execute('DELETE FROM invoicecontents');
+	$DB->Execute('DELETE FROM receiptcontents');
 	
 	if($LMS->CONFIG['database']['type']=='postgres')
 	{
 		$DB->Execute('DROP SEQUENCE "nodes_id_seq"; CREATE SEQUENCE "nodes_id_seq"');
-		$DB->Execute('DROP SEQUENCE "users_id_seq"; CREATE SEQUENCE "users_id_seq"');
+		$DB->Execute('DROP SEQUENCE "customers_id_seq"; CREATE SEQUENCE "customers_id_seq"');
 		$DB->Execute('DROP SEQUENCE "cash_id_seq";  CREATE SEQUENCE "cash_id_seq"');
 		$DB->Execute('DROP SEQUENCE "assignments_id_seq";CREATE SEQUENCE "assignments_id_seq"');
 		$DB->Execute('DROP SEQUENCE "networks_id_seq";   CREATE SEQUENCE "networks_id_seq"');
 		$DB->Execute('DROP SEQUENCE "tariffs_id_seq";    CREATE SEQUENCE "tariffs_id_seq"');
 		$DB->Execute('DROP SEQUENCE "netdevices_id_seq"; CREATE SEQUENCE "netdevices_id_seq"');
 		$DB->Execute('DROP SEQUENCE "netlinks_id_seq";   CREATE SEQUENCE "netlinks_id_seq"');
+		$DB->Execute('DROP SEQUENCE "documents_id_seq";  CREATE SEQUENCE "documents_id_seq"');
+		$DB->Execute('DROP SEQUENCE "taxes_id_seq";  CREATE SEQUENCE "taxes_id_seq"');
 	}
 	
 	if($LMS->CONFIG['database']['type']=='mysql')
 	{
-		$DB->Execute('ALTER TABLE users auto_increment=0');
+		$DB->Execute('ALTER TABLE customers auto_increment=0');
 		$DB->Execute('ALTER TABLE nodes auto_increment=0');
 		$DB->Execute('ALTER TABLE netdevices auto_increment=0');
 		$DB->Execute('ALTER TABLE tariffs auto_increment=0');
+		$DB->Execute('ALTER TABLE taxes auto_increment=0');
 	}
 
-	echo '<B>'.trans('Creating subscriptions...').'</B><BR>';
-	$tariffdata = array( 'name' => 'Lite', 'description' => 'Lite Tariff', 'value' => '30', 'taxvalue' => '7', 'pkwiu' => '', 'uprate' => '64', 'upceil' => '64', 'downrate' => '128', 'downceil' => '128', 'climit' => '0', 'plimit' => '0');
+	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('tax-free', 0, 0));
+	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('7%', 7, 1));
+	$DB->Execute('INSERT INTO taxes (label, value, taxed) VALUES(?,?,?)',array('22%', 22, 1));
+
+	echo '<B>'.trans('Generating subscriptions...').'</B><BR>';
+	$tariffdata = array( 'name' => 'Lite', 'description' => 'Lite Tariff', 'value' => '30', 'taxid' => '1', 'prodid' => '', 'uprate' => '64', 'upceil' => '64', 'downrate' => '128', 'downceil' => '128', 'climit' => '0', 'plimit' => '0');
 	$LMS->TariffAdd($tariffdata);
-	$tariffdata = array( 'name' => 'Standart', 'description' => 'Standart Tariff', 'value' => '60', 'taxvalue' => '7', 'pkwiu' => '', 'uprate' => '128', 'upceil' => '128', 'downrate' => '256', 'downceil' => '256', 'climit' => '0', 'plimit' => '0');
+	$tariffdata = array( 'name' => 'Standart', 'description' => 'Standart Tariff', 'value' => '60', 'taxid' => '2', 'prodid' => '', 'uprate' => '128', 'upceil' => '128', 'downrate' => '256', 'downceil' => '256', 'climit' => '0', 'plimit' => '0');
 	$LMS->TariffAdd($tariffdata);
-	$tariffdata = array( 'name' => 'Gold', 'description' => 'Gold Tariff', 'value' => '120', 'taxvalue' => '7', 'pkwiu' => '', 'uprate' => '256', 'upceil' => '256', 'downrate' => '512', 'downceil' => '512', 'climit' => '0', 'plimit' => '0');
+	$tariffdata = array( 'name' => 'Gold', 'description' => 'Gold Tariff', 'value' => '120', 'taxid' => '3', 'prodid' => '', 'uprate' => '256', 'upceil' => '256', 'downrate' => '512', 'downceil' => '512', 'climit' => '0', 'plimit' => '0');
 	$LMS->TariffAdd($tariffdata);
 
 	echo '<B>'.trans('Generating payments...').'</B><BR>';
-	$paymentdata = array( 'name' => 'DSL-2048', 'description' => 'Internet Link subscription', 'value' => '200', 'creditor' => 'Internet Super Provider Ltd.', 'period' => '1', 'at' => '10');
+	$paymentdata = array( 'name' => 'DSL-2048', 'description' => 'Internet Link subscription', 'value' => '200', 'creditor' => 'Internet Super Provider Ltd.', 'period' => MONTHLY, 'at' => '10');
 	$LMS->PaymentAdd($paymentdata);
-	$paymentdata = array( 'name' => 'Server Room', 'description' => 'Rent', 'value' => '300', 'creditor' => 'Residential Cooperative "VIEW"', 'period' => '1', 'at' => '20');
+	$paymentdata = array( 'name' => 'Server Room', 'description' => 'Rent', 'value' => '300', 'creditor' => 'Residential Cooperative "VIEW"', 'period' => MONTHLY, 'at' => '20');
 	$LMS->PaymentAdd($paymentdata);
-	$paymentdata = array( 'name' => 'Domain', 'description' => 'Domain "our.net" subscription', 'value' => '150', 'creditor' => 'NASK', 'period' => '3', 'at' => '31');
+	$paymentdata = array( 'name' => 'Domain', 'description' => 'Domain "our.net" subscription', 'value' => '150', 'creditor' => 'NASK', 'period' => YEARLY, 'at' => '31');
 	$LMS->PaymentAdd($paymentdata);
 	
 	echo '<B>'.trans('Generating network...').'</B><BR>';
@@ -1897,30 +1908,30 @@ if(isset($_GET['l']) && sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l'])
 	$esize = sizeof($emaildomains);
 	for($i = 0; $i < sprintf('%d',$_GET['l']); $i++)
 	{
-		$useradd['lastname'] = $lastnames[mt_rand(0,$lnsize-1)];
-		$useradd['name'] = $names[mt_rand(0,$nsize-1)];
-		$useradd['phone1'] = $phoneprefix[mt_rand(0,$ppsize-1)];
+		$customeradd['lastname'] = $lastnames[mt_rand(0,$lnsize-1)];
+		$customeradd['name'] = $names[mt_rand(0,$nsize-1)];
+		$customeradd['phone1'] = $phoneprefix[mt_rand(0,$ppsize-1)];
 		for($j = 0; $j < 6; $j++)
-			$useradd['phone1'] .= mt_rand(0,9);
+			$customeradd['phone1'] .= mt_rand(0,9);
 		$street = mt_rand(0,$ssize-1);
-		$useradd['address'] = $streets[$street].' '.mt_rand(1,50).'/'.mt_rand(1,300);
-		$useradd['zip'] = '03-7'.sprintf('%02d',$street);
-		$useradd['city'] = 'Mahagonny';
-		$useradd['email'] = strtolower($useradd['name']).'.'.strtolower($useradd['lastname']).'@'.$emaildomains[mt_rand(0,$esize-1)];
-		$useradd['status'] = 3;
-		$useradd['tariff'] = mt_rand(1,3);
-		$useradd['payday'] = mt_rand(1,28);
-		$useradd['gguin'] = 0;
-		$useradd['phone2'] = '';
-		$useradd['phone3'] = '';
-		$useradd['nip'] = '';
-		$useradd['pesel'] = '';
-		$useradd['serviceaddr'] = '';
-		$useradd['info'] = '';
-		$useradd['message'] = '';
-		$useradd['pin'] = rand(10000,99999);
-		$id = $LMS->UserAdd($useradd);
-		$LMS->AddAssignMent(array( 'tariffid' => $useradd['tariff'], 'userid' => $id, 'period' => 1, 'at' => $useradd['payday'], 'invoice' => 0, 'datefrom' => 0, 'dateto' => 0, 'discount' => 0));
+		$customeradd['address'] = $streets[$street].' '.mt_rand(1,50).'/'.mt_rand(1,300);
+		$customeradd['zip'] = '03-7'.sprintf('%02d',$street);
+		$customeradd['city'] = 'Mahagonny';
+		$customeradd['email'] = strtolower($customeradd['name']).'.'.strtolower($customeradd['lastname']).'@'.$emaildomains[mt_rand(0,$esize-1)];
+		$customeradd['status'] = 3;
+		$customeradd['tariff'] = mt_rand(1,3);
+		$customeradd['payday'] = mt_rand(1,28);
+		$customeradd['im'] = 0;
+		$customeradd['phone2'] = '';
+		$customeradd['phone3'] = '';
+		$customeradd['ten'] = '';
+		$customeradd['ssn'] = '';
+		$customeradd['serviceaddr'] = '';
+		$customeradd['info'] = '';
+		$customeradd['message'] = '';
+		$customeradd['pin'] = rand(10000,99999);
+		$id = $LMS->CustomerAdd($customeradd);
+		$LMS->AddAssignment(array( 'tariffid' => $customeradd['tariff'], 'customerid' => $id, 'period' => MONTHLY, 'at' => $customeradd['payday'], 'invoice' => 0, 'datefrom' => 0, 'dateto' => 0, 'discount' => 0));
 		$nodes = mt_rand(1,2);
 		for($j = 0; $j < $nodes; $j++)
 		{
