@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice_pdf.php,v 1.22.2.3 2005/06/07 16:53:47 alec Exp $
+ *  $Id: invoice_pdf.php,v 1.44 2005/09/13 11:42:41 alec Exp $
  */
 // Faktury w PDF, do uycia z formularzami FT-0100 (c) Polarnet
 // w razie pyta mailto:lexx@polarnet.org
@@ -33,74 +33,6 @@ function text_autosize($x,$y,$size,$text,$width)
     $pdf->addtext($x,$y,$size,$text);
 }
 
-function invoice_simple_form_fill($x,$y,$scale)  
-{
-    global $pdf,$invoice,$_CONFIG;
-    $finances = $_CONFIG['finances'];
-    $pdf->setlinestyle(1);
-
-    $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
-    $pdf->line(7*$scale+$x,724*$scale+$y,37*$scale+$x,724*$scale+$y);
-    $pdf->line(370*$scale+$x,724*$scale+$y,370*$scale+$x,694*$scale+$y);
-    $pdf->line(370*$scale+$x,724*$scale+$y,340*$scale+$x,724*$scale+$y);
-    $pdf->line(7*$scale+$x,197*$scale+$y,7*$scale+$x,227*$scale+$y);
-    $pdf->line(7*$scale+$x,197*$scale+$y,37*$scale+$x,197*$scale+$y);
-    $pdf->line(370*$scale+$x,197*$scale+$y,370*$scale+$x,227*$scale+$y);
-    $pdf->line(370*$scale+$x,197*$scale+$y,340*$scale+$x,197*$scale+$y);
-    
-    text_autosize(15*$scale+$x,568*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$finances['shortname']),350*$scale);
-    text_autosize(15*$scale+$x,534*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$finances['address']),350*$scale);
-    text_autosize(15*$scale+$x,500*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$finances['zip']." ".$finances['city']),350*$scale);
-    $tmp = iconv("UTF-8","ISO-8859-2",$finances['account']);
-    //text_autosize(15*$scale+$x,683*$scale+$y,30*$scale, substr($tmp,0,17),350*$scale);
-    //text_autosize(15*$scale+$x,626*$scale+$y,30*$scale, substr($tmp,18,200),350*$scale);
-    text_autosize(15*$scale+$x,683*$scale+$y,30*$scale, $tmp,350*$scale);
-    text_autosize(15*$scale+$x,445*$scale+$y,30*$scale,"*".number_format($invoice['total'],2,',','')."*",350*$scale);
-
-    text_autosize(15*$scale+$x,390*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['name']),350*$scale);
-    text_autosize(15*$scale+$x,356*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['address']),350*$scale);
-    text_autosize(15*$scale+$x,322*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['zip']." ".$invoice['city']),350*$scale);
-
-    $tmp = $_CONFIG['invoices'];
-    $tmp = iconv("UTF-8","ISO-8859-2",$tmp['number_template']);
-    $tmp = str_replace("%N",$invoice['number'],$tmp);
-    $tmp = str_replace("%Y",$invoice['year'],$tmp);
-    $tmp = str_replace("%M",$invoice['month'],$tmp);
-
-    text_autosize(15*$scale+$x,215*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('Payment for invoice No. $0',$tmp)),350*$scale);
-
-}
-
-function invoice_main_form_fill($x,$y,$scale)	
-{
-    global $pdf,$invoice,$_CONFIG;
-    $finances = $_CONFIG['finances'];
-    $pdf->setlinestyle(1);
-
-    $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
-    $pdf->line(7*$scale+$x,724*$scale+$y,37*$scale+$x,724*$scale+$y);
-    $pdf->line(970*$scale+$x,724*$scale+$y,970*$scale+$x,694*$scale+$y);
-    $pdf->line(970*$scale+$x,724*$scale+$y,940*$scale+$x,724*$scale+$y);
-    $pdf->line(7*$scale+$x,172*$scale+$y,7*$scale+$x,202*$scale+$y);
-    $pdf->line(7*$scale+$x,172*$scale+$y,37*$scale+$x,172*$scale+$y);
-
-    text_autosize(15*$scale+$x,680*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",$finances['name']),950*$scale);
-    text_autosize(15*$scale+$x,617*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",$finances['address']." ".$finances['zip']." ".$finances['city']),950*$scale);
-    text_autosize(15*$scale+$x,555*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",$finances['account']),950*$scale);
-    $pdf->addtext(330*$scale+$x,495*$scale+$y,30*$scale,'X');
-    text_autosize(550*$scale+$x,495*$scale+$y,30*$scale,"*".number_format($invoice['total'],2,',','')."*",400*$scale);
-    text_autosize(15*$scale+$x,434*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('$0 dollars $1 cents',to_words(floor($invoice['total'])),to_words(round(($invoice['total']-floor($invoice['total']))*100)))),950*$scale);
-    text_autosize(15*$scale+$x,372*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['name']),950*$scale);
-    text_autosize(15*$scale+$x,312*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['address']." ".$invoice['zip']." ".$invoice['city']),950*$scale);
-    $tmp = $_CONFIG['invoices'];
-    $tmp = iconv("UTF-8","ISO-8859-2",$tmp['number_template']);
-    $tmp = str_replace("%N",$invoice['number'],$tmp);
-    $tmp = str_replace("%Y",$invoice['year'],$tmp);
-    $tmp = str_replace("%M",$invoice['month'],$tmp);
-    text_autosize(15*$scale+$x,250*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('Payment for invoice No. $0',$tmp)),950*$scale);
-
-}
-
 function text_align_right($x,$y,$size,$text) 
 {
     global $pdf;
@@ -125,7 +57,65 @@ function text_wrap($x,$y,$width,$size,$text,$justify)
     return($y);
 }
 
-function invoice_dates($x,$y) {
+function invoice_simple_form_fill($x,$y,$scale)  
+{
+    global $pdf,$invoice,$CONFIG;
+    $finances = $CONFIG['finances'];
+    $pdf->setlinestyle(1);
+
+    $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
+    $pdf->line(7*$scale+$x,724*$scale+$y,37*$scale+$x,724*$scale+$y);
+    $pdf->line(370*$scale+$x,724*$scale+$y,370*$scale+$x,694*$scale+$y);
+    $pdf->line(370*$scale+$x,724*$scale+$y,340*$scale+$x,724*$scale+$y);
+    $pdf->line(7*$scale+$x,197*$scale+$y,7*$scale+$x,227*$scale+$y);
+    $pdf->line(7*$scale+$x,197*$scale+$y,37*$scale+$x,197*$scale+$y);
+    $pdf->line(370*$scale+$x,197*$scale+$y,370*$scale+$x,227*$scale+$y);
+    $pdf->line(370*$scale+$x,197*$scale+$y,340*$scale+$x,197*$scale+$y);
+    
+    text_autosize(15*$scale+$x,568*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$finances['shortname']),350*$scale);
+    text_autosize(15*$scale+$x,534*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$finances['address']),350*$scale);
+    text_autosize(15*$scale+$x,500*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$finances['zip']." ".$finances['city']),350*$scale);
+    $tmp = bankaccount($invoice['customerid']);
+    //text_autosize(15*$scale+$x,683*$scale+$y,30*$scale, substr($tmp,0,17),350*$scale);
+    //text_autosize(15*$scale+$x,626*$scale+$y,30*$scale, substr($tmp,18,200),350*$scale);
+    text_autosize(15*$scale+$x,683*$scale+$y,30*$scale, $tmp,350*$scale);
+    text_autosize(15*$scale+$x,445*$scale+$y,30*$scale,"*".number_format($invoice['total'],2,',','')."*",350*$scale);
+
+    text_autosize(15*$scale+$x,390*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['name']),350*$scale);
+    text_autosize(15*$scale+$x,356*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['address']),350*$scale);
+    text_autosize(15*$scale+$x,322*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['zip']." ".$invoice['city']),350*$scale);
+
+    $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
+    text_autosize(15*$scale+$x,215*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('Payment for invoice No. $0',$tmp)),350*$scale);
+}
+
+function invoice_main_form_fill($x,$y,$scale)	
+{
+    global $pdf,$invoice,$CONFIG;
+    $finances = $CONFIG['finances'];
+    $pdf->setlinestyle(1);
+
+    $pdf->line(7*$scale+$x,724*$scale+$y,7*$scale+$x,694*$scale+$y);
+    $pdf->line(7*$scale+$x,724*$scale+$y,37*$scale+$x,724*$scale+$y);
+    $pdf->line(970*$scale+$x,724*$scale+$y,970*$scale+$x,694*$scale+$y);
+    $pdf->line(970*$scale+$x,724*$scale+$y,940*$scale+$x,724*$scale+$y);
+    $pdf->line(7*$scale+$x,172*$scale+$y,7*$scale+$x,202*$scale+$y);
+    $pdf->line(7*$scale+$x,172*$scale+$y,37*$scale+$x,172*$scale+$y);
+
+    text_autosize(15*$scale+$x,680*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",$finances['name']),950*$scale);
+    text_autosize(15*$scale+$x,617*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",$finances['address']." ".$finances['zip']." ".$finances['city']),950*$scale);
+    text_autosize(15*$scale+$x,555*$scale+$y,30*$scale,bankaccount($invoice['customerid']),950*$scale);
+    $pdf->addtext(330*$scale+$x,495*$scale+$y,30*$scale,'X');
+    text_autosize(550*$scale+$x,495*$scale+$y,30*$scale,"*".number_format($invoice['total'],2,',','')."*",400*$scale);
+    text_autosize(15*$scale+$x,434*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('$0 dollars $1 cents',to_words(floor($invoice['total'])),to_words(round(($invoice['total']-floor($invoice['total']))*100)))),950*$scale);
+    text_autosize(15*$scale+$x,372*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['name']),950*$scale);
+    text_autosize(15*$scale+$x,312*$scale+$y,30*$scale, iconv("UTF-8","ISO-8859-2",$invoice['address']." ".$invoice['zip']." ".$invoice['city']),950*$scale);
+    $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
+    text_autosize(15*$scale+$x,250*$scale+$y,30*$scale,iconv("UTF-8","ISO-8859-2",trans('Payment for invoice No. $0',$tmp)),950*$scale);
+}
+
+function invoice_dates($x,$y)
+{
     global $invoice,$pdf;
     $font_size=12;
     text_align_right($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('Settlement date:')).' ');
@@ -147,21 +137,20 @@ function invoice_buyer($x,$y)
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['name']));
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['address']));
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$invoice['zip']." ".$invoice['city']));
-    if ($invoice['phone']) $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('Phone:').' '.$invoice['phone']));
-    if ($invoice['nip']) 
-	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('TEN:')).' '.$invoice['nip']);
-    else if ($invoice['pesel']) 
-	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('SSN:')).' '.$invoice['pesel']);
+    if ($invoice['ten']) 
+	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('TEN:')).' '.$invoice['ten']);
+    else if ($invoice['ssn']) 
+	$y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",trans('SSN:')).' '.$invoice['ssn']);
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Customer No.: $0',sprintf('%04d',$invoice['customerid']))).'</b>');
     return $y;
 }
 
 function invoice_seller($x,$y) 
 {
-    global $pdf,$_CONFIG;
+    global $pdf,$CONFIG;
     $font_size=10;
     $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Seller:')).'</b>');
-    $tmp = iconv("UTF-8","ISO-8859-2",$_CONFIG['invoices']['header']);
+    $tmp = iconv("UTF-8","ISO-8859-2",$CONFIG['invoices']['header']);
     $tmp = str_replace('\n',"\n",$tmp);
     $tmp = explode("\n",$tmp);
     foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,$line);
@@ -171,14 +160,27 @@ function invoice_seller($x,$y)
 
 function invoice_title($x,$y) 
 {
-    global $invoice,$pdf,$_CONFIG,$type;
-    $font_size=16;
-    $tmp = $_CONFIG['invoices']['number_template'];
-    $tmp = str_replace("%N",$invoice['number'],$tmp);
-    $tmp = str_replace("%Y",$invoice['year'],$tmp);
-    $tmp = str_replace("%M",$invoice['month'],$tmp);
-    $y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Invoice No. $0',$tmp)).'</b>');
+    global $invoice,$pdf,$CONFIG,$type;
+    $font_size = 16;
+    $tmp = docnumber($invoice['number'], $invoice['template'], $invoice['cdate']);
+    if($invoice['invoice'])
+    	$y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Credit Note No. $0',$tmp)).'</b>');
+    else
+	$y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Invoice No. $0',$tmp)).'</b>');
+    
+    if($invoice['invoice'])
+    {
+	$font_size = 12; $y += 8;
+	$tmp = docnumber($invoice['invoice']['number'], $invoice['invoice']['template'], $invoice['invoice']['cdate']);
+	$y=$y-text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('for Invoice No. $0',$tmp)).'</b>');
+	$y -= 5;
+    }
+    
+    $font_size = 16;
     $y=$y-text_align_left($x,$y,$font_size,iconv("UTF-8","ISO-8859-2",$type));
+    
+    if($invoice['invoice'])
+    	$y += 10;
     return $y;
 }
 
@@ -187,10 +189,10 @@ function invoice_address_box($x,$y)
     global $invoice,$pdf;
     $font_size=12;
     $invoice_name = $invoice['name'];
-        if (strlen($invoice_name)>25)
-		        $invoice_name = preg_replace('/(.{25})/',"$1<i>&gt;</i>\n",$invoice_name);
-	    $tmp = explode("\n",iconv("UTF-8","ISO-8859-2",$invoice_name));
-	    foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,"<b>".$line."</b>");
+    if (strlen($invoice_name)>25) 
+        $invoice_name = preg_replace('/(.{25})/',"$1<i>&gt;</i>\n",$invoice_name);
+    $tmp = explode("\n",iconv("UTF-8","ISO-8859-2",$invoice_name));
+    foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,"<b>".$line."</b>");
     if ($invoice['serviceaddr']) {
 	$tmp = explode("\n",iconv("UTF-8","ISO-8859-2",$invoice['serviceaddr']));
 	foreach ($tmp as $line) $y=$y-text_align_left($x,$y,$font_size,"<b>".$line."</b>");
@@ -263,15 +265,15 @@ function invoice_data($x,$y,$width,$font_size,$margin)
     $t_data[10] = '<b>'.iconv("UTF-8","ISO-8859-2",trans('Gross Value:')).'</b>';
     for ($i = 1; $i <= 10; $i++) $t_justify[$i]="left";
     for ($i = 1; $i <= 10; $i++) $t_width[$i]=$pdf->getTextWidth($font_size,$t_data[$i])+2*$margin+1;
-    // tutaj jeszcze trzeba bdzie sprawdzi jak szeroko maj pola w tabelce puniej
+    // tutaj jeszcze trzeba bdzie sprawdzi jak szeroko maj pola w tabelce pniej
     if ($invoice['content']) foreach ($invoice['content'] as $item) {
 	$tt_width[2] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",$item['description']));
-	$tt_width[3] = $pdf->getTextWidth($font_size,$item['pkwiu']);
+	$tt_width[3] = $pdf->getTextWidth($font_size,$item['prodid']);
 	$tt_width[4] = $pdf->getTextWidth($font_size,$item['content']);
 	$tt_width[5] = $pdf->getTextWidth($font_size,$item['count']);
 	$tt_width[6] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['basevalue'])));
 	$tt_width[7] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['totalbase'])));
-	$tt_width[8] = $pdf->getTextWidth($font_size,$item['taxvalue']." %");
+	$tt_width[8] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",$item['taxlabel']));
 	$tt_width[9] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['totaltax'])));
 	$tt_width[10] = $pdf->getTextWidth($font_size,iconv("UTF-8","ISO-8859-2",moneyf($item['total'])));
 	for ($i = 2; $i <= 5; $i++) if (($tt_width[$i]+2*margin+2)>$t_width[$i]) $t_width[$i]=$tt_width[$i]+2*margin+2;
@@ -280,19 +282,77 @@ function invoice_data($x,$y,$width,$font_size,$margin)
     $t_width[2] = $width-($t_width[1]+$t_width[3]+$t_width[4]+$t_width[5]+$t_width[6]+$t_width[7]+$t_width[8]+$t_width[9]+$t_width[10]+20*$margin);
     $y = invoice_data_row($x,$y,$width,$font_size,$margin,$t_data,$t_width,$t_justify);
     $t_justify[10] = $t_justify[9] = $t_justify[8] = $t_justify[7] = $t_justify[6] = $t_justify[5] = "right";
+
+    if($invoice['invoice'])
+    {
+	// we have credit note, so first print corrected invoice data
+	$xx = $x;
+        $y = $y-text_align_left($x,$y-10,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Was:')).'</b>');
+	$y -= 6;
+	$pdf->line($x,$y,$x+$width,$y);
+	$lp = 1;
+	if ($invoice['invoice']['content']) 
+	    foreach ($invoice['invoice']['content'] as $item)
+	    {
+		$t_data[1] = $lp;
+		$t_data[2] = iconv("UTF-8","ISO-8859-2",$item['description']);
+		$t_data[3] = $item['prodid'];
+		$t_data[4] = $item['content'];
+		$t_data[5] = sprintf('%.2f',$item['count']);
+		$t_data[6] = iconv("UTF-8","ISO-8859-2",moneyf($item['basevalue']));
+		$t_data[7] = iconv("UTF-8","ISO-8859-2",moneyf($item['totalbase']));
+		$t_data[8] = iconv("UTF-8","ISO-8859-2",$item['taxlabel']);
+		$t_data[9] = iconv("UTF-8","ISO-8859-2",moneyf($item['totaltax']));
+		$t_data[10] = iconv("UTF-8","ISO-8859-2",moneyf($item['total']));
+	
+		$lp++;
+		$y = invoice_data_row($x,$y,$width,$font_size,$margin,$t_data,$t_width,$t_justify);
+	    }
+    
+        $x = $x + 12*$margin + $t_width[1] + $t_width[2] + $t_width[3] + $t_width[4] + $t_width[5] + $t_width[6];
+
+        $fy=$y-$margin-$pdf->GetFontHeight($font_size);    
+	text_align_right($x-$margin,$fy,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Total:')).'</b>');
+    
+	$t_data[7] = iconv("UTF-8","ISO-8859-2",moneyf($invoice['invoice']['totalbase']));
+        $t_data[8] = "<b>x</b>";
+	$t_data[9] = iconv("UTF-8","ISO-8859-2",moneyf($invoice['invoice']['totaltax']));
+        $t_data[10] = iconv("UTF-8","ISO-8859-2",moneyf($invoice['invoice']['total']));
+    
+	$y = invoice_short_data_row($x,$y,$width,$font_size,$margin,$t_data,$t_width,$t_justify);
+        $y -= 5;
+
+	$fy=$y-$margin-$pdf->GetFontHeight($font_size);    
+        text_align_right($x-$margin,$fy,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('in it:')).'</b>');
+	$pdf->line($x,$y,$x+$t_width[7]+$t_width[8]+$t_width[9]+$t_width[10]+8*$margin,$y);
+    
+	if ($invoice['invoice']['taxest']) 
+	    foreach ($invoice['invoice']['taxest'] as $item) 
+	    {
+		$t_data[7] = iconv("UTF-8","ISO-8859-2",moneyf($item['base']));
+		$t_data[8] = iconv("UTF-8","ISO-8859-2",$item['taxlabel']);
+		$t_data[9] = iconv("UTF-8","ISO-8859-2",moneyf($item['tax']));
+		$t_data[10] = iconv("UTF-8","ISO-8859-2",moneyf($item['total']));
+		$y = invoice_short_data_row($x,$y,$width,$font_size,$margin,$t_data,$t_width,$t_justify);
+	    }
+	
+	$x = $xx;
+	$y = $y-text_align_left($x,$y-10,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Corrected to:')).'</b>');
+	$y -= 5;
+	$pdf->line($x,$y,$x+$width,$y);
+    }
+        
     $lp = 1;
-    if ($invoice['content']) foreach ($invoice['content'] as $item) {
+    if ($invoice['content']) foreach ($invoice['content'] as $item)
+    {
 	$t_data[1] = $lp;
 	$t_data[2] = iconv("UTF-8","ISO-8859-2",$item['description']);
-	$t_data[3] = $item['pkwiu'];
+	$t_data[3] = $item['prodid'];
 	$t_data[4] = $item['content'];
-	$t_data[5] = $item['count'];
+	$t_data[5] = sprintf('%.2f',$item['count']);
 	$t_data[6] = iconv("UTF-8","ISO-8859-2",moneyf($item['basevalue']));
 	$t_data[7] = iconv("UTF-8","ISO-8859-2",moneyf($item['totalbase']));
-	if ($item['taxvalue']) 
-	    $t_data[8] = $item['taxvalue']." %";
-	else
-	    $t_data[8] = iconv("UTF-8","ISO-8859-2",trans('Tax-free'));
+	$t_data[8] = iconv("UTF-8","ISO-8859-2",$item['taxlabel']);
 	$t_data[9] = iconv("UTF-8","ISO-8859-2",moneyf($item['totaltax']));
 	$t_data[10] = iconv("UTF-8","ISO-8859-2",moneyf($item['total']));
 	
@@ -323,37 +383,41 @@ function invoice_data($x,$y,$width,$font_size,$margin)
     if ($invoice['taxest']) foreach ($invoice['taxest'] as $item) 
     {
 	$t_data[7] = iconv("UTF-8","ISO-8859-2",moneyf($item['base']));
-	$t_data[8] = $item['taxvalue']." %";
+	$t_data[8] = iconv("UTF-8","ISO-8859-2",$item['taxlabel']);
 	$t_data[9] = iconv("UTF-8","ISO-8859-2",moneyf($item['tax']));
 	$t_data[10] = iconv("UTF-8","ISO-8859-2",moneyf($item['total']));
 	$y = invoice_short_data_row($x,$y,$width,$font_size,$margin,$t_data,$t_width,$t_justify);
     }
     $return[2] = $y;
+
     return $return;
 }
 
 function invoice_to_pay($x,$y) 
 {
     global $pdf, $invoice;
-    $y = $y - text_align_left($x,$y,14,iconv("UTF-8","ISO-8859-2",trans('To pay:')).' '.iconv("UTF-8","ISO-8859-2",moneyf($invoice['total'])));
-    $y = $y - text_align_left($x,$y,10,iconv("UTF-8","ISO-8859-2",trans('In words:')).' '.iconv("UTF-8","ISO-8859-2",trans('$0 dollars $1 cents',to_words(floor($invoice['total'])),to_words(round(($invoice['total']-floor($invoice['total']))*100)))));
+    if($invoice['rebate'])
+	    $y = $y - text_align_left($x,$y,14,iconv("UTF-8","ISO-8859-2",trans('To repay:')).' '.iconv("UTF-8","ISO-8859-2",moneyf($invoice['value'])));
+    else
+	    $y = $y - text_align_left($x,$y,14,iconv("UTF-8","ISO-8859-2",trans('To pay:')).' '.iconv("UTF-8","ISO-8859-2",moneyf($invoice['value'])));
+    $y = $y - text_align_left($x,$y,10,iconv("UTF-8","ISO-8859-2",trans('In words:')).' '.iconv("UTF-8","ISO-8859-2",trans('$0 dollars $1 cents',to_words(floor($invoice['value'])),to_words(round(($invoice['value']-floor($invoice['value']))*100)))));
     return $y;
 }
 
 function invoice_expositor ($x,$y) 
 {
-    global $pdf, $_CONFIG;
-    $y = $y - text_align_left($x,$y,10,iconv("UTF-8","ISO-8859-2",trans('Expositor:')).' '.iconv("UTF-8","ISO-8859-2",$_CONFIG['invoices']['default_author']));
+    global $pdf, $CONFIG;
+    $y = $y - text_align_left($x,$y,10,iconv("UTF-8","ISO-8859-2",trans('Expositor:')).' '.iconv("UTF-8","ISO-8859-2",$CONFIG['invoices']['default_author']));
     return $y;
 }
 
 function invoice_footnote($x, $y, $width, $font_size) 
 {
-    global $pdf, $_CONFIG;
-    if ($_CONFIG['invoices']['footer']) {
+    global $pdf, $CONFIG;
+    if ($CONFIG['invoices']['footer']) {
 	$y = $y - $pdf->getFontHeight($font_size);
 	$y = $y - text_align_left($x,$y,$font_size,'<b>'.iconv("UTF-8","ISO-8859-2",trans('Notes:')).'</b>');
-	$tmp = iconv("UTF-8","ISO-8859-2",$_CONFIG['invoices']['footer']);
+	$tmp = iconv("UTF-8","ISO-8859-2",$CONFIG['invoices']['footer']);
 	$tmp = str_replace('\n',"\n",$tmp);
         $tmp = explode("\n",$tmp);
 	foreach ($tmp as $line) $y = text_wrap($x,$y,$width,$font_size,$line,"full");
@@ -362,8 +426,15 @@ function invoice_footnote($x, $y, $width, $font_size)
 
 function invoice_body() 
 {
-    global $invoice,$pdf,$id,$_CONFIG;
-    switch ($_CONFIG['invoices']['template_file']) {
+    global $invoice,$pdf,$id,$CONFIG;
+    
+    if($invoice['invoice'])
+	    $template = $CONFIG['invoices']['cnote_template_file'];
+    else
+	    $template = $CONFIG['invoices']['template_file'];
+
+    switch ($template)
+    {
 	case "standard":
 	    $top=800;
 	    invoice_dates(500,800);    
@@ -400,7 +471,7 @@ function invoice_body()
 	    invoice_simple_form_fill(14,3,0.4);
 	    break;
 	default:
-	    require($_CONFIG['invoices']['template_file']);
+	    require($template);
     }
     if (!($invoice['last'])) $id=$pdf->newPage(1,$id,'after');
 }
@@ -429,35 +500,43 @@ $pdf->selectFont($_LIB_DIR.'/ezpdf/arial.afm',array('encoding'=>'WinAnsiEncoding
 
 $id=$pdf->getFirstPageId();
 
-if($_GET['print'] == 'cached' && sizeof($_POST['marks']))
+if($_GET['print'] == 'cached')
 {
-	$layout['pagetitle'] = iconv("UTF-8","ISO-8859-2",trans('Invoices'));
+	$SESSION->restore('ilm', $ilm);
+	$SESSION->remove('ilm');
 
-	foreach($_POST['marks'] as $markid => $junk)
-		if($junk)
-			$ids[] = $markid;
+	if(sizeof($_POST['marks']))
+		foreach($_POST['marks'] as $id => $mark)
+			$ilm[$id] = $mark;
+
+	if(sizeof($ilm))
+		foreach($ilm as $mark)
+			$ids[] = $mark;
+
+	if(!sizeof($ids))
+	{
+		$SESSION->close();
+		die;
+	}
 
 	if($_GET['cash'])
 	{
 		foreach($ids as $cashid)
-			if($invoiceid = $LMS->DB->GetOne('SELECT invoiceid FROM cash WHERE id = ?', array($cashid)))
+			if($invoiceid = $DB->GetOne('SELECT docid FROM cash, documents WHERE docid = documents.id AND documents.type = 1 AND cash.id = ?', array($cashid)))
 				$idsx[] = $invoiceid;
-		if(!$idsx)
-			$SESSION->redirect('?m=invoicelist');
 		
-		$ids = array_unique($idsx);
+		$ids = array_unique((array)$idsx);
 	}
 
 	sort($ids);
 	$which = ($_GET['which'] != '' ? $_GET['which'] : trans('ORIGINAL+COPY'));
-	
 	$count = (strstr($which,'+') ? sizeof($ids)*2 : sizeof($ids));
 	$i=0;
 
 	foreach($ids as $idx => $invoiceid)
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
-		$invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
+		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
 		foreach(split('\+', $which) as $type)
 		{
 			$i++;
@@ -468,12 +547,11 @@ if($_GET['print'] == 'cached' && sizeof($_POST['marks']))
 }
 elseif($_GET['fetchallinvoices'])
 {
-	$layout['pagetitle'] = iconv("UTF-8","ISO-8859-2",trans('Invoices'));
 	$which = ($_GET['which'] != '' ? $_GET['which'] : trans('ORIGINAL+COPY'));
 	
-	$ids = $LMS->DB->GetCol('SELECT id FROM invoices 
-				WHERE cdate > ? AND cdate < ?'
-				.($_GET['userid'] ? ' AND customerid = '.$_GET['userid'] : '')
+	$ids = $DB->GetCol('SELECT id FROM documents
+				WHERE cdate > ? AND cdate < ? AND type = 1'
+				.($_GET['customerid'] ? ' AND customerid = '.$_GET['customerid'] : '')
 				.' ORDER BY cdate',
 				array($_GET['from'], $_GET['to']));
 	if(!$ids)
@@ -488,7 +566,7 @@ elseif($_GET['fetchallinvoices'])
 	foreach($ids as $idx => $invoiceid)
 	{
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
-		$invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
+		$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
 		foreach(split('\+', $which) as $type)
 		{
 			$i++;
@@ -500,16 +578,15 @@ elseif($_GET['fetchallinvoices'])
 elseif($_GET['fetchsingle'])
 {
 	$invoice = $LMS->GetInvoiceContent($_GET['id']);
-	$layout['pagetitle'] = iconv("UTF-8","ISO-8859-2",trans('Invoice No. $0', $ntempl));
 	$invoice['last'] = TRUE;
-	$invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
+	$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
+	$type = trans('ORIGINAL');
 	invoice_body();
 
 }
 elseif($invoice = $LMS->GetInvoiceContent($_GET['id']))
 {
-	$layout['pagetitle'] = iconv("UTF-8","ISO-8859-2",trans('Invoice No. $0', $ntempl));
-	$invoice['serviceaddr'] = $LMS->GetUserServiceAddress($invoice['customerid']);
+	$invoice['serviceaddr'] = $LMS->GetCustomerServiceAddress($invoice['customerid']);
 	$type = trans('ORIGINAL');
 	invoice_body();
 	$type = trans('COPY');
@@ -521,8 +598,6 @@ else
 	$SESSION->redirect('?m=invoicelist');
 }
 
-global $pdf;
-
 $pdf->ezStream();
 
 ?>
