@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,13 +21,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicenew.php,v 1.34.2.2 2005/05/20 11:44:40 kondi Exp $
+ *  $Id: invoicenew.php,v 1.44 2005/09/11 14:32:32 hunter Exp $
  */
 
 $layout['pagetitle'] = trans('New Invoice');
 
-$users = $LMS->GetUserNames();
+$customers = $LMS->GetCustomerNames();
 $tariffs = $LMS->GetTariffs();
+$taxeslist = $LMS->GetTaxes();
+$numberplanlist = $LMS->GetNumberPlans(DOC_INVOICE);
 $SESSION->restore('invoicecontents', $contents);
 $SESSION->restore('invoicecustomer', $customer);
 $SESSION->restore('invoice', $invoice);
@@ -42,42 +44,36 @@ switch($_GET['action'])
     		unset($contents);
     		unset($customer);
     		unset($error);
-		
-		$invoice['number'] = $LMS->GetNewInvoiceNumber();
-		$invoice['month'] = date("m");
-		$invoice['year']  = date("Y");
+
+		// get default invoice's numberplanid and next number
+		$invoice['numberplanid'] = $DB->GetOne('SELECT id FROM numberplans WHERE doctype=? AND isdefault=1', array(DOC_INVOICE));
+		$invoice['number'] = $LMS->GetNewDocumentNumber(DOC_INVOICE, $invoice['numberplanid']);
 		$invoice['cdate'] = time();
 		$invoice['paytime'] = 14;
-		if($_GET['userid'] != '' && $LMS->UserExists($_GET['userid']))
-			$customer = $LMS->GetUser($_GET['userid']);
+		if($_GET['customerid'] != '' && $LMS->CustomerExists($_GET['customerid']))
+			$customer = $LMS->GetCustomer($_GET['customerid']);
 	break;
 
 	case 'additem':
 		$itemdata = r_trim($_POST);
 		foreach(array('count', 'valuenetto', 'valuebrutto') as $key)
-			$itemdata[$key] = round((float) str_replace(',','.',$itemdata[$key]),2);
-		if ($itemdata['taxvalue'] != '')
-			$itemdata['taxvalue'] = round((float) str_replace(',','.',$itemdata['taxvalue']),2);
+			$itemdata[$key] = f_round($itemdata[$key]);
 		
 		if($itemdata['count'] > 0 && $itemdata['name'] != '')
 		{
-			$taxvalue = $itemdata['taxvalue'];
-			if ($taxvalue == '')
-				$taxvalue = 0;
-			if($taxvalue < 0 || $taxvalue > 100)
-				$error['taxvalue'] = trans('Incorrect tax value!');
+			$taxvalue = $taxeslist[$itemdata['taxid']]['value'];
 			if($itemdata['valuenetto'] != 0)
 				$itemdata['valuebrutto'] = round($itemdata['valuenetto'] * ($taxvalue / 100 + 1),2);
 			elseif($itemdata['valuebrutto'] != 0)
 				$itemdata['valuenetto'] = round($itemdata['valuebrutto'] / ($taxvalue + 100) * 100, 2);
 			
-			// str_replace here is needed because of bug in some PHP versions
-			$itemdata['s_valuenetto'] = str_replace(',','.',$itemdata['valuenetto'] * $itemdata['count']);
-			$itemdata['s_valuebrutto'] = str_replace(',','.',$itemdata['valuebrutto'] * $itemdata['count']);
-			$itemdata['taxvalue'] = str_replace(',','.',$itemdata['taxvalue']);
-			$itemdata['valuenetto'] = str_replace(',','.',$itemdata['valuenetto']);
-			$itemdata['valuebrutto'] = str_replace(',','.',$itemdata['valuebrutto']);
-			$itemdata['count'] = str_replace(',','.',$itemdata['count']);
+			// str_replace->f_round here is needed because of bug in some PHP versions
+			$itemdata['s_valuenetto'] = f_round($itemdata['valuenetto'] * $itemdata['count']);
+			$itemdata['s_valuebrutto'] = f_round($itemdata['valuebrutto'] * $itemdata['count']);
+			$itemdata['valuenetto'] = f_round($itemdata['valuenetto']);
+			$itemdata['valuebrutto'] = f_round($itemdata['valuebrutto']);
+			$itemdata['count'] = f_round($itemdata['count']);
+			$itemdata['tax'] = $taxeslist[$itemdata['taxid']]['label'];
 			$itemdata['posuid'] = (string) getmicrotime();
 			$contents[] = $itemdata;
 		}
@@ -92,8 +88,6 @@ switch($_GET['action'])
 
 	case 'setcustomer':
 
-		$oldmonth = $invoice['month'];
-		$oldyear  = $invoice['year'];		
 		unset($invoice); 
 		unset($customer);
 		unset($error);
@@ -107,7 +101,7 @@ switch($_GET['action'])
 		if($invoice['paytime'] < 0)
 			$invoice['paytime'] = 14;
 
-		$invoice['userid'] = $_POST['userid'];
+		$invoice['customerid'] = $_POST['customerid'];
 		
 		if($invoice['cdate'])
 		{
@@ -115,31 +109,18 @@ switch($_GET['action'])
 			if(checkdate($month, $day, $year)) 
 			{
 				$invoice['cdate'] = mktime(date('G',time()),date('i',time()),date('s',time()),$month,$day,$year);
-				
-				if (($oldmonth!=$month) || ($oldyear!=$year))
-				{
-					$invoice['month'] = $month;
-					$invoice['year']  = $year;
-				} 
-				else 
-				{
-					$invoice['month'] = $oldmonth;
-					$invoice['year']  = $oldyear;
-				}
 			}
 			else
 			{
 				$error['cdate'] = trans('Incorrect date format!');
 				$invoice['cdate'] = time();
-				$invoice['month'] = $oldmonth;
-				$invoice['year']  = $oldyear;
 				break;
 			}
 		}
 
 		if($invoice['cdate'] && !$invoice['cdatewarning'])
 		{
-			$maxdate = $LMS->DB->GetOne('SELECT MAX(cdate) FROM invoices');
+			$maxdate = $DB->GetOne('SELECT MAX(cdate) FROM documents WHERE type = 1');
 			if($invoice['cdate'] < $maxdate)
 			{
 				$error['cdate'] = trans('Last date of invoice settlement is $0. If sure, you want to write invoice with date of $1, then click "Submit" again.',date('Y/m/d H:i', $maxdate), date('Y/m/d H:i', $invoice['cdate']));
@@ -148,18 +129,18 @@ switch($_GET['action'])
 		}
 
 		if(!$invoice['number'])
-			$invoice['number'] = $LMS->GetNewInvoiceNumber($invoice['cdate']);
+			$invoice['number'] = $LMS->GetNewDocumentNumber(DOC_INVOICE, $invoice['numberplanid'], $invoice['cdate']);
 		else
 		{
 			if(!eregi('^[0-9]+$', $invoice['number']))
 				$error['number'] = trans('Invoice number must be integer!');
-			elseif($LMS->InvoiceExists($invoice['number'], $invoice['cdate']))
+			elseif($LMS->DocumentExists($invoice['number'], DOC_INVOICE, $invoice['numberplanid'], $invoice['cdate']))
 				$error['number'] = trans('Invoice number $0 already exists!', $invoice['number']);
 		}
 		
 		if(!$error)
-			if($LMS->UserExists(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['user'])))
-				$customer = $LMS->GetUser(($_GET['userid'] != '' ? $_GET['userid'] : $_POST['user']));
+			if($LMS->CustomerExists(($_GET['customerid'] != '' ? $_GET['customerid'] : $_POST['customer'])))
+				$customer = $LMS->GetCustomer(($_GET['customerid'] != '' ? $_GET['customerid'] : $_POST['customer']));
 
 	break;
 
@@ -167,6 +148,7 @@ switch($_GET['action'])
 
 		if($contents && $customer)
 		{
+			$invoice['type'] = DOC_INVOICE;
 			$iid = $LMS->AddInvoice(array('customer' => $customer, 'contents' => $contents, 'invoice' => $invoice));
 		
 			$SESSION->remove('invoicecontents');
@@ -197,7 +179,9 @@ $SMARTY->assign('contents', $contents);
 $SMARTY->assign('customer', $customer);
 $SMARTY->assign('invoice', $invoice);
 $SMARTY->assign('tariffs', $tariffs);
-$SMARTY->assign('users', $users);
+$SMARTY->assign('customers', $customers);
+$SMARTY->assign('taxeslist', $taxeslist);
+$SMARTY->assign('numberplanlist', $numberplanlist);
 $SMARTY->display('invoicenew.html');
 
 ?>
