@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevlist.php,v 1.15.2.1 2005/05/13 20:10:04 alec Exp $
+ *  $Id: netdevlist.php,v 1.17 2005/07/14 17:07:24 alec Exp $
  */
 
 $layout['pagetitle'] = trans('Network Devices');
@@ -40,14 +40,14 @@ unset($netdevlist['total']);
 unset($netdevlist['order']);
 unset($netdevlist['direction']);
 
-if ($SESSION->is_set('nlp') && !isset($_GET['page']))
-        $SESSION->restore('nlp', $_GET['page']);
+if ($SESSION->is_set('ndlp') && !isset($_GET['page']))
+        $SESSION->restore('ndlp', $_GET['page']);
 	
 $page = (! $_GET['page'] ? 1 : $_GET['page']);
 $pagelimit = (! $LMS->CONFIG['phpui']['nodelist_pagelimit'] ? $listdata['total'] : $LMS->CONFIG['phpui']['nodelist_pagelimit']);
 $start = ($page - 1) * $pagelimit;
 
-$SESSION->save('nlp', $page);
+$SESSION->save('ndlp', $page);
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
