@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,22 +21,22 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevmap.php,v 1.44.2.1 2005/05/13 20:10:04 alec Exp $
+ *  $Id: netdevmap.php,v 1.46 2005/05/27 15:59:04 alec Exp $
  */
 
 function drawtext($x, $y, $text, $r, $g, $b)
 {
-	global $m, $font, $_CONFIG;
+	global $m, $font, $CONFIG;
 
 	if(!$text) return;
 
-	if($_CONFIG['phpui']['gd_translate_to'])
-		$text = iconv('UTF-8', $_CONFIG['phpui']['gd_translate_to'], $text);
+	if($CONFIG['phpui']['gd_translate_to'])
+		$text = iconv('UTF-8', $CONFIG['phpui']['gd_translate_to'], $text);
 
 	// remove special characters because we haven't got proper font
 	// or something else. I don't know what, but we have a problem with 
 	// that characters on flash map.
-	if(strtoupper($_CONFIG['phpui']['gd_translate_to'])=='ISO-8859-2')
+	if(strtoupper($CONFIG['phpui']['gd_translate_to'])=='ISO-8859-2')
 	{
 		// for Polish diacritical chars
 		$from = array('','','','','','','','','','','','','','','','','','');
@@ -55,9 +55,9 @@ function drawtext($x, $y, $text, $r, $g, $b)
 
 function pngdrawtext($image, $font, $x, $y, $text, $color, $bgcolor)
 {
-	global $_CONFIG;
-	if($_CONFIG['phpui']['gd_translate_to'])
-		$text = iconv('UTF-8', $_CONFIG['phpui']['gd_translate_to'], $text);
+	global $CONFIG;
+	if($CONFIG['phpui']['gd_translate_to'])
+		$text = iconv('UTF-8', $CONFIG['phpui']['gd_translate_to'], $text);
 	imagestring($image, $font, $x + 1, $y + 1, $text, $bgcolor);
 	imagestring($image, $font, $x + 1, $y - 1, $text, $bgcolor);
 	imagestring($image, $font, $x - 1, $y + 1, $text, $bgcolor);
@@ -252,7 +252,7 @@ if($graph == '')
 	$SMARTY->assign('nodemap', $nodemap);
 	$SMARTY->assign('deviceslist', $deviceslist);
 	$SMARTY->assign('start', $start);
-	$SMARTY->assign('type', strtolower($_CONFIG['phpui']['map_type']));
+	$SMARTY->assign('type', strtolower($CONFIG['phpui']['map_type']));
 	$SMARTY->assign('emptydb', sizeof($deviceslist) ? FALSE : TRUE);
 	$SMARTY->assign('gd', function_exists('imagepng'));
 	$SMARTY->assign('ming', function_exists('ming_useswfversion'));
