@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeinfo.php,v 1.43.2.2 2005/05/20 11:44:41 kondi Exp $
+ *  $Id: nodeinfo.php,v 1.50 2005/10/07 19:09:11 alec Exp $
  */
 
 if(!eregi('^[0-9]+$',$_GET['id']))
@@ -32,7 +32,7 @@ if(!eregi('^[0-9]+$',$_GET['id']))
 if(!$LMS->NodeExists($_GET['id']))
 	if(isset($_GET['ownerid']))
 	{
-		$SESSION->redirect('?m=userinfo&id='.$_GET['ownerid']);
+		$SESSION->redirect('?m=customerinfo&id='.$_GET['ownerid']);
 	}
 	else
 	{
@@ -53,13 +53,14 @@ if(isset($_GET['devid']))
 $nodeid = $_GET['id'];
 $ownerid = $LMS->GetNodeOwner($nodeid);
 $tariffs = $LMS->GetTariffs();
-$userinfo = $LMS->GetUser($ownerid);
+$customerinfo = $LMS->GetCustomer($ownerid);
 $nodeinfo = $LMS->GetNode($nodeid);
-$balancelist = $LMS->GetUserBalanceList($ownerid);
-$assignments = $LMS->GetUserAssignments($ownerid);
-$usergroups = $LMS->UsergroupGetForUser($ownerid);
-$otherusergroups = $LMS->GetGroupNamesWithoutUser($ownerid);
-$contractlist = $LMS->GetContractList();
+$balancelist = $LMS->GetCustomerBalanceList($ownerid);
+$assignments = $LMS->GetCustomerAssignments($ownerid);
+$documents = $LMS->GetDocuments($ownerid, 10);
+$customergroups = $LMS->CustomergroupGetForCustomer($ownerid);
+$othercustomergroups = $LMS->GetGroupNamesWithoutCustomer($ownerid);
+$taxeslist = $LMS->GetTaxes();
 
 $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
@@ -75,14 +76,14 @@ $layout['pagetitle'] = trans('Node Info: $0',$nodeinfo['name']);
 
 $SMARTY->assign('netdevices',$netdevices);
 $SMARTY->assign('balancelist',$balancelist);
-$SMARTY->assign('userinfo',$userinfo);
+$SMARTY->assign('customerinfo',$customerinfo);
 $SMARTY->assign('nodeinfo',$nodeinfo);
 $SMARTY->assign('assignments',$assignments);
-$SMARTY->assign('usergroups',$usergroups);
-$SMARTY->assign('otherusergroups',$otherusergroups);
+$SMARTY->assign('customergroups',$customergroups);
+$SMARTY->assign('othercustomergroups',$othercustomergroups);
+$SMARTY->assign('documents', $documents);
+$SMARTY->assign('taxeslist', $taxeslist);
 $SMARTY->assign('tariffs',$tariffs);
-$SMARTY->assign('contractlist',$contractlist);
-$SMARTY->assign('contractcount',sizeof($contractlist));
 $SMARTY->display('nodeinfo.html');
 
 ?>
