@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodelist.php,v 1.38.2.1 2005/05/13 20:10:05 alec Exp $
+ *  $Id: nodelist.php,v 1.40 2005/06/28 09:01:42 alec Exp $
  */
 
 $layout['pagetitle'] = trans('Nodes List');
@@ -34,12 +34,26 @@ else
 	$o = $_GET['o'];
 $SESSION->save('nlo', $o);
 
-$nodelist = $LMS->GetNodeList($o);
+if(!isset($_GET['s']))
+	$SESSION->restore('nls', $s);
+else
+	$s = $_GET['s'];
+$SESSION->save('nls', $s);
+
+if(!isset($_GET['n']))
+	$SESSION->restore('nln', $n);
+else
+	$n = $_GET['n'];
+$SESSION->save('nln', $n);
+
+$nodelist = $LMS->GetNodeList($o, NULL, NULL, $n, $s);
 $listdata['total'] = $nodelist['total'];
 $listdata['order'] = $nodelist['order'];
 $listdata['direction'] = $nodelist['direction'];
 $listdata['totalon'] = $nodelist['totalon'];
 $listdata['totaloff'] = $nodelist['totaloff'];
+$listdata['network'] = $n;
+$listdata['state'] = $s;
 
 unset($nodelist['total']);
 unset($nodelist['order']);
@@ -61,6 +75,7 @@ $SMARTY->assign('pagelimit',$pagelimit);
 $SMARTY->assign('start',$start);
 $SMARTY->assign('nodelist',$nodelist);
 $SMARTY->assign('listdata',$listdata);
+$SMARTY->assign('networks',$LMS->GetNetworks());
 $SMARTY->display('nodelist.html');
 
 ?>
