@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,12 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodelistshort.php,v 1.1.2.1 2005/05/13 20:10:05 alec Exp $
+ *  $Id: nodelistshort.php,v 1.3 2005/05/26 11:33:03 alec Exp $
  */
 
-$usernodes = $LMS->GetUserNodes($_GET['id']);
+$customernodes = $LMS->GetCustomerNodes($_GET['id']);
 
-$SMARTY->assign('usernodes',$usernodes);
+$SMARTY->assign('customernodes',$customernodes);
 $SMARTY->display('nodelistshort.html');
 
 
