@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentadd.php,v 1.10.2.1 2005/05/13 20:10:05 alec Exp $
+ *  $Id: paymentadd.php,v 1.12 2005/07/23 17:21:40 alec Exp $
  */
 
 $payment = $_POST['payment'];
@@ -51,17 +51,20 @@ if(isset($payment))
 
 	$period = sprintf('%d',$payment['period']);
 	
-	if($period < 0 || $period > 3)
-		$period = 1;
+	if($period < DAILY || $period > YEARLY)
+		$period = MONTHLY;
 
 	switch($period)
 	{
-		case 0:
+		case DAILY:
+			$at = 0;
+		break;
+		case WEEKLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at < 1 || $at > 7)
 				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
-		case 1:
+		case MONTHLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at == 0)
 			{
@@ -72,7 +75,7 @@ if(isset($payment))
 			if($at < 1 || $at > 28)
 		    		$error['at'] = trans('Incorrect day of month (1-28)!');
 		break;
-		case 2:
+		case QUARTERLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = trans('Incorrect date format!');
 			else {
@@ -85,7 +88,7 @@ if(isset($payment))
 				$at = ($m-1) * 100 + $d;
 			};
 		break;
-		case 3:
+		case YEARLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = trans('Incorrect date format!');
 			else
