@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: paymentedit.php,v 1.11.2.1 2005/05/13 20:10:05 alec Exp $
+ *  $Id: paymentedit.php,v 1.13 2005/07/23 17:21:40 alec Exp $
  */
 
 if(!$LMS->PaymentExists($_GET['id']))
@@ -53,18 +53,22 @@ if(isset($payment))
 
 	$period = sprintf('%d',$payment['period']);
 	
-	if($period < 0 || $period > 3)
-		$period = 1;
+	if($period < DAILY || $period > YEARLY)
+		$period = MONTHLY;
 
 	switch($period)
 	{
-		case 0:
+		case DAILY:
+			$at = 0;
+		break;
+
+		case WEEKLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at < 1 || $at > 7)
 				$error['at'] = trans('Incorrect day of week (1-7)!');
 		break;
 		
-		case 1:
+		case MONTHLY:
 			$at = sprintf('%d',$payment['at']);
 			if($at == 0)
 			{
@@ -76,7 +80,7 @@ if(isset($payment))
 				$error['at'] = trans('Incorrect day of month (1-28)!');
 		break;
 			
-		case 2:
+		case QUARTERLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = 'Niepoprawny format daty';
 			else {
@@ -90,7 +94,7 @@ if(isset($payment))
 			};
 		break;
 		
-		case 3:
+		case YEARLY:
 			if(!eregi('^[0-9]{2}/[0-9]{2}$',trim($payment['at'])))
 				$error['at'] = trans('Incorrect date format!');
 			else
@@ -113,9 +117,9 @@ if(isset($payment))
 } else 
 {
 	$payment = $LMS->GetPayment($_GET['id']);
-	if($payment['period']==3)
+	if($payment['period'] == YEARLY)
 		$payment['at'] = date('d/m',($payment['at']-1)*86400);
-	if($payment['period']==2)
+	if($payment['period'] == QUARTERLY)
 		$payment['at'] = sprintf('%02d/%02d',($payment['at']%100),$payment['at']/100+1);
 }
 	
