@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: reload.php,v 1.33.2.1 2005/05/13 20:10:06 alec Exp $
+ *  $Id: reload.php,v 1.37 2005/08/29 19:18:47 alec Exp $
  */
 
 $layout['pagetitle'] = trans('Configuration Reload');
@@ -36,18 +36,50 @@ $_EXECCMD = $LMS->CONFIG['phpui']['reload_execcmd'];
 switch($_RELOAD_TYPE)
 {
 	case 'exec':
-		$execlist = explode(';',$_EXECCMD);
-		echo '<TABLE WIDTH="100%" BGCOLOR="#F4F0EC" CELLPADDING="5"><TR><TD CLASS="FALL">';
-		foreach($execlist as $execcmd)
+		$hosts = $DB->GetAll('SELECT id, name, lastreload, reload, description FROM hosts ORDER BY name');
+
+		if(isset($_GET['setreloads']))
 		{
-			echo '<P><B>'.$execcmd.'</B>:</P>';
-			echo '<PRE>';
-			flush();
-			echo passthru($execcmd);
-			flush();
-			echo '</PRE>';
+			echo '<TABLE WIDTH="100%" BGCOLOR="#F4F0EC" CELLPADDING="5"><TR><TD CLASS="FALL">';
+			$execlist = explode(';',$_EXECCMD);
+			foreach($hosts as $host)
+				if(in_array($host['id'], (array) $_POST['hosts']))
+					foreach($execlist as $execcmd)
+					{
+						$execcmd = str_replace('%host', $host['name'], $execcmd);
+						echo '<P><B>'.$execcmd.'</B>:</P>';
+						echo '<PRE>';
+						flush();
+						echo passthru($execcmd);
+						flush();
+						echo '</PRE>';
+					}
+			echo '</TD></TR></TABLE>';
+		}
+		else
+		{
+			if(!count($hosts))
+			{
+				echo '<TABLE WIDTH="100%" BGCOLOR="#F4F0EC" CELLPADDING="5"><TR><TD CLASS="FALL">';
+				$execlist = explode(';',$_EXECCMD);
+				foreach($execlist as $execcmd)
+				{
+					$execcmd = str_replace('%host', '', $execcmd);
+					echo '<P><B>'.$execcmd.'</B>:</P>';
+					echo '<PRE>';
+					flush();
+					echo passthru($execcmd);
+					flush();
+					echo '</PRE>';
+				}
+				echo '</TD></TR></TABLE>';
+			}
+			else
+			{
+				$SMARTY->assign('hosts', $hosts);
+				$SMARTY->display('reload.html');
+			}
 		}
-		echo '</TD></TR></TABLE>';
 	break;
 
 	case 'sql':
@@ -60,23 +92,21 @@ switch($_RELOAD_TYPE)
 				$query = str_replace('%TIME%','?NOW?',$query);
 				echo '<P><B>'.trans('Running:').'</B></P>';
 				echo '<PRE>'.$query.'</PRE>';
-				$LMS->DB->Execute($query);
+				$DB->Execute($query);
 			}
 			echo '</TD></TR></TABLE>';
 		}
 		else
 		{
-			$hosts = $LMS->DB->GetAll('SELECT id, name, lastreload, reload, description FROM daemonhosts ORDER BY name');
+			$hosts = $DB->GetAll('SELECT id, name, lastreload, reload, description FROM hosts ORDER BY name');
 			
 			if(isset($_GET['setreloads']))
 			{
 				foreach($hosts as $host)
 					if(in_array($host['id'], (array) $_POST['hosts']))
-						$LMS->DB->Execute('UPDATE daemonhosts SET reload=1 WHERE id=?', array($host['id']));
+						$DB->Execute('UPDATE hosts SET reload=1 WHERE id=?', array($host['id']));
 					else
-						$LMS->DB->Execute('UPDATE daemonhosts SET reload=0 WHERE id=?', array($host['id']));
-				
-				$LMS->SetTS('daemonhosts');
+						$DB->Execute('UPDATE hosts SET reload=0 WHERE id=?', array($host['id']));
 			}
 			
 			$SMARTY->assign('hosts', $hosts);
