@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueedit.php,v 1.6.2.2 2005/05/20 11:44:42 kondi Exp $
+ *  $Id: rtqueueedit.php,v 1.9 2005/05/27 15:35:21 alec Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
@@ -41,9 +41,9 @@ if(isset($queue))
 	if($queue['email']!='' && !check_email($queue['email']))
 		$error['email'] = trans('Incorrect email!');
 
-	if(isset($queue['admins']))
-		foreach($queue['admins'] as $key => $value)
-			$queue['rights'][] = array('id' => $key, 'rights' => $value, 'name' => $queue['adminnames'][$key]);
+	if(isset($queue['users']))
+		foreach($queue['users'] as $key => $value)
+			$queue['rights'][] = array('id' => $key, 'rights' => $value, 'name' => $queue['usernames'][$key]);
 
 	if(!$error)
 	{
