@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtqueueview.php,v 1.19.2.1 2005/05/13 20:10:06 alec Exp $
+ *  $Id: rtqueueview.php,v 1.21 2005/05/27 15:35:21 alec Exp $
  */
 
 if(! $LMS->QueueExists($_GET['id']))
@@ -31,7 +31,7 @@ if(! $LMS->QueueExists($_GET['id']))
 
 $queuedata['id'] = $_GET['id'];
 
-if(! $LMS->GetAdminRightsRT($AUTH->id, $queuedata['id']))
+if(! $LMS->GetUserRightsRT($AUTH->id, $queuedata['id']))
 {
 	$SMARTY->display('noaccess.html');
 	$SESSION->close();
