@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketadd.php,v 1.20.2.3 2005/05/27 06:07:06 alec Exp $
+ *  $Id: rtticketadd.php,v 1.29 2005/07/05 13:16:41 alec Exp $
  */
 
 $ticket = $_POST['ticket'];
@@ -36,7 +36,7 @@ if(isset($ticket))
 		$SESSION->redirect('?m=rtticketadd&id='.$queue);
 	}
 
-	if($LMS->GetAdminRightsRT($AUTH->id, $queue) < 2)
+	if($LMS->GetUserRightsRT($AUTH->id, $queue) < 2)
 		$error['queue'] = trans('You have no privileges to this queue!');
 
 	if($ticket['subject'] == '')
@@ -48,10 +48,10 @@ if(isset($ticket))
 	if($ticket['email']!='' && !check_email($ticket['email']))
 		$error['email'] = trans('Incorrect email!');
 
-	if($ticket['userid'] !=0 && $ticket['custid']!=$ticket['userid'])
+	if($ticket['customerid'] !=0 && $ticket['custid']!=$ticket['customerid'])
 		$error['custid'] = trans('Specified ID is not proper or does not exist!');
 
-	if($ticket['surname']=='' && $ticket['userid']==0)
+	if($ticket['surname']=='' && $ticket['customerid']==0)
 		$error['surname'] = trans('Requester name required!');
 
 	$requestor  = ($ticket['surname'] ? $ticket['surname'].' ' : '');
@@ -67,17 +67,17 @@ if(isset($ticket))
 		
 		if($LMS->CONFIG['phpui']['newticket_notify'])
 		{
-			$admin = $LMS->GetAdminInfo($AUTH->id);
+			$user = $LMS->GetUserInfo($AUTH->id);
 
 			if($mailfname = $LMS->CONFIG['phpui']['helpdesk_sender_name'])
 			{
 				if($mailfname == 'queue') $mailfname = $LMS->GetQueueName($queue);
-				if($mailfname == 'user') $mailfname = $admin['name'];
+				if($mailfname == 'user') $mailfname = $user['name'];
 				$mailfname = '"'.$mailfname.'"';
 			}
 
-			if ($admin['email'])
-				$mailfrom = $admin['email'];
+			if ($user['email'])
+				$mailfrom = $user['email'];
 			elseif ($qemail = $LMS->GetQueueEmail($queue))
 				$mailfrom = $qemail;
 			else
@@ -92,7 +92,7 @@ if(isset($ticket))
 				.$_SERVER['HTTP_HOST'].substr($_SERVER['REQUEST_URI'], 0, strrpos($_SERVER['REQUEST_URI'], '/') + 1)
 				.'?m=rtticketview&id='.$id;
 
-			if($recipients = $LMS->DB->GetCol('SELECT email FROM admins, rtrights WHERE admins.id=adminid AND queueid=? AND email!=\'\' AND rtrights.rights>2',array($queue)))
+			if($recipients = $DB->GetCol('SELECT email FROM users, rtrights WHERE users.id=userid AND queueid=? AND email!=\'\' AND rtrights.rights>2',array($queue)))
 				foreach($recipients as $email)
 				{
 					if($LMS->CONFIG['phpui']['debug_email'])
@@ -116,8 +116,8 @@ $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 $SMARTY->assign('ticket', $ticket);
 $SMARTY->assign('queue', $queue);
 $SMARTY->assign('queuelist', $LMS->GetQueueNames());
-$SMARTY->assign('userid', isset($ticket['userid']) ? $ticket['userid'] : $_GET['userid']);
-$SMARTY->assign('userlist', $LMS->GetUserNames());
+$SMARTY->assign('customerid', isset($ticket['customerid']) ? $ticket['customerid'] : $_GET['customerid']);
+$SMARTY->assign('customerlist', $LMS->GetAllCustomerNames());
 $SMARTY->assign('error', $error);
 $SMARTY->display('rtticketadd.html');
 
