@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,14 +21,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketedit.php,v 1.13.2.2 2005/05/20 11:44:42 kondi Exp $
+ *  $Id: rtticketedit.php,v 1.16 2005/05/27 15:35:21 alec Exp $
  */
 
 $ticketedit = $_POST['ticket'];
 
 if(($id = $_GET['id']) && !isset($ticketedit))
 {
-	if($LMS->GetAdminRightsRT($AUTH->id, 0, $id) < 2)
+	if($LMS->GetUserRightsRT($AUTH->id, 0, $id) < 2)
 	{
 		$SMARTY->display('noaccess.html');
 		$SESSION->close();
@@ -47,7 +47,7 @@ $ticket = $LMS->GetTicketContents($id);
 if(isset($ticketedit))
 {
 	$ticketedit['ticketid'] = $ticket['ticketid'];
-	if($LMS->GetAdminRightsRT($AUTH->id, $ticketedit['queueid']) < 2)
+	if($LMS->GetUserRightsRT($AUTH->id, $ticketedit['queueid']) < 2)
 		$error['queue'] = trans('You have no privileges to this queue!');
 	
 	if($ticketedit['subject'] == '')
@@ -78,7 +78,7 @@ $SESSION->save('backto', $_SERVER['QUERY_STRING']);
 
 $SMARTY->assign('ticket', $ticket);
 $SMARTY->assign('queuelist', $LMS->GetQueueNames());
-$SMARTY->assign('adminlist', $LMS->GetAdminNames());
+$SMARTY->assign('userlist', $LMS->GetUserNames());
 $SMARTY->assign('error', $error);
 $SMARTY->display('rtticketedit.html');
 
