@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: rtticketprint.php,v 1.7.2.1 2005/05/13 20:10:07 alec Exp $
+ *  $Id: rtticketprint.php,v 1.9 2005/05/27 15:35:21 alec Exp $
  */
 
 if(! $LMS->TicketExists($_GET['id']))
@@ -29,7 +29,7 @@ if(! $LMS->TicketExists($_GET['id']))
 	$SESSION->redirect('?m=rtqueuelist');
 }
 
-if(! $LMS->GetAdminRightsRT($AUTH->id, 0, $_GET['id']))
+if(! $LMS->GetUserRightsRT($AUTH->id, 0, $_GET['id']))
 {
 	$SMARTY->display('noaccess.html');
 	$SESSION->close();
