@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffadd.php,v 1.42.2.2 2005/05/20 11:44:42 kondi Exp $
+ *  $Id: tariffadd.php,v 1.46 2005/06/30 10:05:02 alec Exp $
  */
 
 $tariffadd = $_POST['tariffadd'];
@@ -41,10 +41,6 @@ if(isset($tariffadd))
 	if(!(ereg('^[-]?[0-9.,]+$',$tariffadd['value'])))
 		$error['value'] = trans('Incorrect subscription value!');
 
-	if($tariffadd['taxvalue']!='')
-		if(!(ereg('^[0-9.,]+$',$tariffadd['taxvalue'])) || $tariffadd['taxvalue'] < 0 || $tariffadd['taxvalue'] > 100)
-			$error['taxvalue'] = trans('Incorrect tax rate!');
-
 	if($tariffadd['uprate']=='') $tariffadd['uprate'] = 0;
 	if($tariffadd['downrate']=='') $tariffadd['downrate'] = 0;
 	if($tariffadd['upceil']=='') $tariffadd['upceil'] = 0;
@@ -80,6 +76,9 @@ if(isset($tariffadd))
 		if($LMS->GetTariffIDByName($tariffadd['name']))
 			$error['name'] = trans('Subscription $0 already exists!',$tariffadd['name']);
 
+	if(!$tariffadd['taxid'])
+		$tariffadd['taxid'] = 0;
+		
 	if(!$error)
 	{
 		$SESSION->redirect('?m=tarifflist&id='.$LMS->TariffAdd($tariffadd));
@@ -91,6 +90,7 @@ $layout['pagetitle'] = trans('New Subscription');
 
 $SMARTY->assign('error',$error);
 $SMARTY->assign('tariffadd',$tariffadd);
+$SMARTY->assign('taxeslist',$LMS->GetTaxes());
 $SMARTY->display('tariffadd.html');
 
 ?>
