@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,10 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffdelete.php,v 1.22.2.1 2005/05/13 20:10:07 alec Exp $
+ *  $Id: tariffdelete.php,v 1.24 2005/05/26 11:33:03 alec Exp $
  */
 
-if(!$LMS->GetUsersWithTariff($_GET['id'])&&$_GET['is_sure']="1")
+if(!$LMS->GetCustomersWithTariff($_GET['id'])&&$_GET['is_sure']="1")
 	$LMS->TariffDelete($_GET['id']);	
 
 $SESSION->redirect('?m=tarifflist');
