@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffedit.php,v 1.30.2.2 2005/05/20 11:44:42 kondi Exp $
+ *  $Id: tariffedit.php,v 1.34 2005/06/30 10:05:02 alec Exp $
  */
 
 if(!$LMS->TariffExists($_GET['id']))
@@ -55,10 +55,6 @@ if(isset($tariff))
 	elseif(!(ereg('^[-]?[0-9.,]+$', $tariff['value'])))
 		$error['value'] = trans('Incorrect value!');
 	
-	if($tariff['taxvalue'] != '')
-	  	if(!(ereg('^[0-9.,]+$', $tariff['taxvalue'])) || $tariff['taxvalue'] < 0 || $tariff['taxvalue'] > 100)
-			$error['taxvalue'] = trans('Incorrect tax rate!');
-
 	if(!(ereg("^[0-9]+$", $tariff['uprate'])))
 		$error['uprate'] = trans('Integer value expected!');
 	if(!ereg('^[0-9]+$', $tariff['downrate']))
@@ -81,6 +77,8 @@ if(isset($tariff))
 	if(($tariff['downceil'] < 8 || $tariff['downceil'] < $tariff['downrate']) && $tariff['downceil'] != 0)
 		$error['downceil'] = trans('This field must be greater than 8 and greater than download rate');
 
+	if(!$tariff['taxid'])
+		$tariff['taxid'] = 0;
 
 	$tariff['id'] = $_GET['id'];
 
@@ -94,7 +92,9 @@ if(isset($tariff))
 	$tariff = $LMS->GetTariff($_GET['id']);
 	
 $layout['pagetitle'] = trans('Subscription Edit: $0',$tariff['name']);
+
 $SMARTY->assign('tariff',$tariff);
+$SMARTY->assign('taxeslist',$LMS->GetTaxes());
 $SMARTY->assign('error',$error);
 $SMARTY->display('tariffedit.html');
 
