@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.6.1 Ishta
+ * LMS version 1.7.4 Wraith
  *
  *  (C) Copyright 2001-2005 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.43.2.1 2005/05/13 20:10:08 alec Exp $
+ *  $Id: welcome.php,v 1.46 2005/05/26 13:24:57 alec Exp $
  */
 
 require_once($_LIB_DIR.'/Sysinfo.class.php');
@@ -31,14 +31,14 @@ $SI = new Sysinfo;
 
 $layout['pagetitle'] = 'LAN Management System';
 
-$layout['dbversion'] = $LMS->DB->GetDBVersion();
+$layout['dbversion'] = $DB->GetDBVersion();
 $layout['dbtype'] = $LMS->CONFIG['database']['type'];
 
 $SMARTY->assign('updates', $LMS->CheckUpdates());
 $SMARTY->assign('regdata', $LMS->GetRegisterData());
 $SMARTY->assign('rtstats', $LMS->RTStats());
 $SMARTY->assign('sysinfo',$SI->get_sysinfo());
-$SMARTY->assign('userstats',$LMS->UserStats());
+$SMARTY->assign('customerstats',$LMS->CustomerStats());
 $SMARTY->assign('nodestats',$LMS->NodeStats());
 $SMARTY->display('welcome.html');
 
